@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This file is Copyright 2002
@@ -16,25 +16,27 @@
     COPYING included with this distribution for more information.
 */
 
+#include "AnalysisTypes.h"
+
+#include "NotationTypes.h"
+#include "Pitch.h"
+#include "Event.h"
+#include "Segment.h"
+#include "CompositionTimeSliceAdapter.h"
+#include "BaseProperties.h"
+#include "Composition.h"
+#include "Sets.h"
+#include "Quantizer.h"
+
+#include "misc/Strings.h"
+
+#include <assert.h>
 #include <iostream>
 #include <string>
 #include <map>
 #include <algorithm>
 #include <cmath> // fabs, pow
 
-#include "base/NotationTypes.h"
-#include "AnalysisTypes.h"
-#include "Event.h"
-#include "base/Segment.h"
-#include "CompositionTimeSliceAdapter.h"
-#include "base/BaseProperties.h"
-#include "Composition.h"
-
-#include "Sets.h"
-#include "Quantizer.h"
-
-#include <assert.h>
-
 
 namespace Rosegarden
 {
@@ -51,7 +53,7 @@ using std::partial_sort_copy;
 ///////////////////////////////////////////////////////////////////////////
 
 Key
-AnalysisHelper::getKeyForEvent(Event *e, Segment &s)
+AnalysisHelper::getKeyForEvent(const Event *e, Segment &s)
 {
     Segment::iterator i =
         e ? s.findNearestTime(e->getAbsoluteTime()) //cc
@@ -147,7 +149,7 @@ ChordLabel::ChordLabel()
     checkMap();
 }
 
-ChordLabel::ChordLabel(Key key, int mask, int /* bass */) :
+ChordLabel::ChordLabel(const Key& key, int mask, int /* bass */) :
     m_data()
 {
     checkMap();
@@ -182,7 +184,8 @@ ChordLabel::ChordLabel(Key key, int mask, int /* bass */) :
 std::string
 ChordLabel::getName(Key /* key */) const
 {
-    return Pitch(m_data.m_rootPitch).getAsString(false) + m_data.m_type;
+    return qstrtostr(Pitch::toString(m_data.m_rootPitch)) + m_data.m_type;
+    //return Pitch(m_data.m_rootPitch).getAsString(false) + m_data.m_type;
         // + (m_data.m_inversion>0 ? " in first inversion" : "");
 }
 
@@ -689,10 +692,10 @@ AnalysisHelper::addProgressionToMap(Key k,
          ChordTypes::Minor, ChordTypes::Major, ChordTypes::Major,
          ChordTypes::Minor, ChordTypes::Diminished};
 
-    int offset = k.getTonicPitch();
-
     if (!k.isMinor())
     {
+        int offset = k.getTonicPitch();
+
         ChordLabel firstChord
         (
             majorDiationicTriadTypes[firstChordNumber],
@@ -853,7 +856,7 @@ AnalysisHelper::PitchProfile::operator+=(const PitchProfile& d)
 // should use constants for basic lengths, not numbers
 
 TimeSignature
-AnalysisHelper::guessTimeSignature(CompositionTimeSliceAdapter &c)
+AnalysisHelper::guessTimeSignature(const CompositionTimeSliceAdapter &c)
 {
     bool haveNotes = false;
 
@@ -866,10 +869,13 @@ AnalysisHelper::guessTimeSignature(CompositionTimeSliceAdapter &c)
     // durations of quaver, dotted quaver, crotchet, dotted crotchet:
     static const int commonBeatDurations[4] = {48, 72, 96, 144};
 
-    int j = 0;
+    // This appears to be an iteration limiter.  It's never used other than
+    // to restrict the computation to no more than 100 iterations.
+    int iterations = 0;
+
     for (CompositionTimeSliceAdapter::iterator i = c.begin();
-         i != c.end() && j < 100;
-         ++i, ++j)
+         i != c.end() && iterations < 100;
+         ++i, ++iterations)
     {
 
         // Skip non-notes
@@ -905,12 +911,12 @@ AnalysisHelper::guessTimeSignature(CompositionTimeSliceAdapter &c)
     int beatDuration = 0,
         bestScore = 0;
 
-    for (int j = 0; j < 4; ++j)
+    for (int i = 0; i < 4; ++i)
     {
-        if (beatScores[j] >= bestScore)
+        if (beatScores[i] >= bestScore)
         {
-            bestScore = beatScores[j];
-            beatDuration = commonBeatDurations[j];
+            bestScore = beatScores[i];
+            beatDuration = commonBeatDurations[i];
         }
     }
 
@@ -921,8 +927,8 @@ AnalysisHelper::guessTimeSignature(CompositionTimeSliceAdapter &c)
     vector<int> measureLengthScores(5, 0);
 
     for (CompositionTimeSliceAdapter::iterator i = c.begin();
-         i != c.end() && j < 100;
-         ++i, ++j)
+         i != c.end() && iterations < 100;
+         ++i, ++iterations)
     {
 
         if (!(*i)->isa(Note::EventType)) continue;
@@ -958,12 +964,12 @@ AnalysisHelper::guessTimeSignature(CompositionTimeSliceAdapter &c)
 
     bestScore = 0;  // reused from earlier
 
-    for (int j = 2; j < 5; ++j)
+    for (int i = 2; i < 5; ++i)
     {
-        if (measureLengthScores[j] >= bestScore)
+        if (measureLengthScores[i] >= bestScore)
         {
-            bestScore = measureLengthScores[j];
-            measureLength = j;
+            bestScore = measureLengthScores[i];
+            measureLength = i;
         }
     }
 
@@ -1025,7 +1031,7 @@ AnalysisHelper::guessKey(CompositionTimeSliceAdapter &c)
         timeT time = (*i)->getAbsoluteTime();
 
         if (time >= nextSigTime) {
-            Composition *comp = c.getComposition();
+            const Composition *comp = c.getComposition();
             int sigNo = comp->getTimeSignatureNumberAt(time);
             if (sigNo >= 0) {
                 std::pair<timeT, TimeSignature> sig = comp->getTimeSignatureChange(sigNo);
@@ -1129,7 +1135,7 @@ AnalysisHelper::guessKeyAtTime(Composition &comp, timeT t,
     for (SegmentMultiSet::iterator i = segs.begin();
          i != segs.end();
          ++i) {
-        Segment *s = *i;
+        const Segment *s = *i;
         // If this segment is relevant...
         if ((s != segmentToSkip) &&
             (s->getStartTime() <= t) &&
