@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -33,8 +33,8 @@ public:
     explicit Exception(const std::string& message);
     Exception(const std::string& message, const std::string& file, int line);
 
-    explicit Exception(QString message);
-    Exception(QString message, QString file, int line);
+    explicit Exception(const QString& message);
+    Exception(const QString& message, QString file, int line);
 
     ~Exception() throw () override {}
 
