@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -180,7 +180,7 @@ namespace Marks
      * text mark containing that string.  For example, the Sforzando
      * mark is actually defined as getTextMark("sf").
      */
-    extern ROSEGARDENPRIVATE_EXPORT Mark getTextMark(std::string text);
+    extern ROSEGARDENPRIVATE_EXPORT Mark getTextMark(const std::string& text);
 
     /**
      * Return true if the given mark is a text mark.
@@ -198,7 +198,8 @@ namespace Marks
      * instead of a number to permit "fingering" marks containing
      * labels like "+".)
      */
-    extern ROSEGARDENPRIVATE_EXPORT Mark getFingeringMark(std::string fingering);
+    extern ROSEGARDENPRIVATE_EXPORT Mark getFingeringMark
+    (const std::string& fingering);
 
     /**
      * Return true if the given mark is a fingering mark.
@@ -213,7 +214,7 @@ namespace Marks
     /**
      * Return true if the given mark makes sense when applied to a rest.
      */
-    extern ROSEGARDENPRIVATE_EXPORT bool isApplicableToRests(Mark mark);
+    extern ROSEGARDENPRIVATE_EXPORT bool isApplicableToRests(const Mark& mark);
 
     /**
      * Extract the number of marks from an event.
@@ -242,7 +243,8 @@ namespace Marks
      * there to remove.  If the mark was not unique, removes only
      * the first instance of it.
      */
-    extern ROSEGARDENPRIVATE_EXPORT bool removeMark(Event &e, const Mark &mark);
+    extern ROSEGARDENPRIVATE_EXPORT bool removeMark
+    (Event &e, const Mark &markToRemove);
 
     /**
      * Returns true if the event has the given mark.
@@ -304,7 +306,7 @@ public:
      * exception if the given string does not match one of the above
      * clef name constants.
      */
-    Clef(const std::string &s, int octaveOffset = 0);
+    explicit Clef(const std::string &s, int octaveOffset = 0);
 
     Clef(const Clef &c) : m_clef(c.m_clef), m_octaveOffset(c.m_octaveOffset) {
     }
@@ -577,7 +579,7 @@ public:
      * For example: transposing F major by a major triad (4,2) yields
      *  A major.
      */
-    Key transpose(int pitchDelta, int heightDelta);
+    Key transpose(int pitchDelta, int heightDelta) const;
 
 private:
     std::string m_name;
@@ -732,8 +734,8 @@ public:
 
     explicit Text(const Event &e)
         /* throw (Event::NoData, Event::BadType) */;
-    Text(const std::string &text,
-         const std::string &textType = UnspecifiedType);
+    explicit Text(const std::string &text,
+                  const std::string &textType = UnspecifiedType);
     Text(const Text &);
     Text &operator=(const Text &);
     ~Text();
@@ -769,274 +771,6 @@ private:
 
 
 
-/**
- * Pitch stores a note's pitch and provides information about it in
- * various different ways, notably in terms of the position of the
- * note on the staff and its associated accidental.
- *
- * (See docs/discussion/units.txt for explanation of pitch units.)
- *
- * This completely replaces the older NotationDisplayPitch class.
- */
-
-class ROSEGARDENPRIVATE_EXPORT Pitch
-{
-public:
-    /**
-     * Construct a Pitch object based on the given Event, which must
-     * have a BaseProperties::PITCH property.  If the property is
-     * absent, NoData is thrown.  The BaseProperties::ACCIDENTAL
-     * property will also be used if present.
-     */
-    explicit Pitch(const Event &e)
-        /* throw Event::NoData */;
-
-    /**
-     * Construct a Pitch object based on the given performance (MIDI) pitch.
-     */
-    Pitch(int performancePitch,
-          const Accidental &explicitAccidental = Accidentals::NoAccidental);
-
-    /**
-     * Construct a Pitch based on octave and pitch in octave.  The
-     * lowest permissible octave number is octaveBase, and middle C is
-     * in octave octaveBase + 5.  pitchInOctave must be in the range
-     * 0-11 where 0 is C, 1 is C sharp, etc.
-     */
-    Pitch(int pitchInOctave, int octave,
-          const Accidental &explicitAccidental = Accidentals::NoAccidental,
-          int octaveBase = -2);
-
-    /**
-     * Construct a Pitch based on octave and note in scale.  The
-     * lowest permissible octave number is octaveBase, and middle C is
-     * in octave octaveBase + 5.  The octave supplied should be that
-     * of the root note in the given key, which may be in a different
-     * MIDI octave from the resulting pitch (as MIDI octaves always
-     * begin at C).  noteInScale must be in the range 0-6 where 0 is
-     * the root of the key and so on.  The accidental is relative to
-     * noteInScale: if there is an accidental in the key for this note
-     * already, explicitAccidental will be "added" to it.
-     *
-     * For minor keys, the harmonic scale is used.
-     */
-    Pitch(int noteInScale, int octave, const Key &key,
-          const Accidental &explicitAccidental = Accidentals::NoAccidental,
-          int octaveBase = -2);
-
-    /**
-     * Construct a Pitch based on (MIDI) octave, note in the C major scale and
-     * performance pitch. The accidental is calculated based on these
-     * properties.
-     */
-    Pitch(int noteInCMajor, int octave, int pitch,
-          int octaveBase = -2);
-
-    /**
-     * Construct a Pitch based on octave and note name.  The lowest
-     * permissible octave number is octaveBase, and middle C is in
-     * octave octaveBase + 5.  noteName must be a character in the
-     * range [CDEFGAB] or lower-case equivalents.  The key is supplied
-     * so that we know how to interpret the NoAccidental case.
-     */
-    Pitch(char noteName, int octave, const Key &key,
-          const Accidental &explicitAccidental = Accidentals::NoAccidental,
-          int octaveBase = -2);
-
-    /**
-     * Construct a Pitch corresponding a staff line or space on a
-     * classical 5-line staff.  The bottom staff line has height 0,
-     * the top has height 8, and both positive and negative values are
-     * permissible.
-     */
-    Pitch(int heightOnStaff, const Clef &clef, const Key &key,
-          const Accidental &explicitAccidental = Accidentals::NoAccidental);
-
-    Pitch(const Pitch &);
-    Pitch &operator=(const Pitch &);
-
-    /**
-     * Return the MIDI pitch for this Pitch object.
-     */
-    int getPerformancePitch() const;
-
-    /**
-     * Return the accidental for this pitch using a bool to prefer sharps over
-     * flats if there is any doubt.  This is the accidental
-     * that would be used to display this pitch outside of the context
-     * of any key; that is, it may duplicate an accidental actually in
-     * the current key.  This should not be used if you need to get an
-     * explicit accidental returned for E#, Fb, B# or Cb.
-     *
-     * This version of the function exists to avoid breaking old code.
-     */
-    Accidental getAccidental(bool useSharps) const;
-
-    /**
-     * Return the accidental for this pitch, using a key.  This should be used
-     * if you need an explicit accidental returned for E#, Fb, B# or Cb, which
-     * can't be resolved correctly without knowing that their key requires
-     * them to take an accidental.  The provided key will also be used to
-     * determine whether to prefer sharps over flats.
-     */
-    Accidental getAccidental(const Key &key) const;
-
-    /**
-     * Return the accidental that should be used to display this pitch
-     * in a given key.  For example, if the pitch is F-sharp in a key
-     * in which F has a sharp, NoAccidental will be returned.  (This
-     * is in contrast to getAccidental, which would return Sharp.)
-     * This obviously can't take into account things like which
-     * accidentals have already been displayed in the bar, etc.
-     */
-    Accidental getDisplayAccidental(const Key &key) const;
-
-    /**
-     * Return the accidental that should be used to display this pitch
-     * in a given key, using the given strategy to resolve pitches where
-     * an accidental is needed but not specified.
-     */
-    Accidental getDisplayAccidental(const Key &key, Accidentals::NoAccidentalStrategy) const;
-
-    /**
-     * Return the position in the scale for this pitch, as a number in
-     * the range 0 to 6 where 0 is the root of the key.
-     */
-    int getNoteInScale(const Key &key) const;
-
-    /**
-     * Return the note name for this pitch, as a single character in
-     * the range A to G.  (This is a reference value that should not
-     * normally be shown directly to the user, for i18n reasons.)
-     */
-    char getNoteName(const Key &key) const;
-
-    /**
-     * Return the height at which this pitch should display on a
-     * conventional 5-line staff.  0 is the bottom line, 1 the first
-     * space, etc., so for example middle-C in the treble clef would
-     * return -2.
-     *
-     * Chooses the most likely accidental for this pitch in this key.
-     */
-    int getHeightOnStaff(const Clef &clef, const Key &key) const;
-
-    /**
-     * Return the height at which this pitch should display on a
-     * conventional 5-line staff.  0 is the bottom line, 1 the first
-     * space, etc., so for example middle-C in the treble clef would
-     * return -2.
-     *
-     * Chooses the accidental specified by the 'useSharps' parameter
-     */
-    int getHeightOnStaff(const Clef &clef, bool useSharps) const;
-
-    /**
-     * Return the octave containing this pitch.  The octaveBase argument
-     * specifies the octave containing MIDI pitch 0; middle-C is in octave
-     * octaveBase + 5.
-     */
-    int getOctave(int octaveBase = -2) const;
-
-    /**
-     * Return the octave containing this pitch, including the accidentals.
-     * The octaveBase argument specifies the octave containing MIDI pitch 0;
-     * middle-C is in octave octaveBase + 5.
-     */
-    int getOctaveAccidental(int octaveBase = -2, const Accidental& acc = Accidentals::NoAccidental) const;
-
-    /**
-     * Return the pitch within the octave, in the range 0 to 11.
-     */
-    int getPitchInOctave() const;
-
-    /**
-     * Return whether this pitch is diatonic in the given key.
-     */
-    bool isDiatonicInKey(const Key &key) const;
-
-    /**
-     * Return a reference name for this pitch.  (C 4, Bb 2, etc...)
-     * using the key of C major explicitly, which should allow the accidentals
-     * to take their natural forms of C# Eb F# G# Ab Bb from the key, rather
-     * than being forced sharp explicilty.
-     *
-     * This replaces an earlier version of this function that took a "use
-     * sharps" argument to return either sharps or flats, which broke after
-     * Arnout Engelen did some really nice accidental spelling improvements to
-     * make everything more human.
-     */
-    std::string getAsString(bool inclOctave = true,
-                            int octaveBase = -2) const;
-
-    /**
-     * Return a number 0-6 corresponding to the given note name, which
-     * must be in the range [CDEFGAB] or lower-case equivalents.  The
-     * return value is in the range 0-6 with 0 for C, 1 for D etc.
-     */
-    static int getIndexForNote(char noteName);
-
-    /**
-     * Return a note name corresponding to the given note index, which
-     * must be in the range 0-6 with 0 for C, 1 for D etc.
-     */
-    static char getNoteForIndex(int index);
-
-    /**
-     * Calculate and return the performance (MIDI) pitch corresponding
-     * to the stored height and accidental, interpreting them as
-     * Rosegarden-2.1-style values (for backward compatibility use),
-     * in the given clef and key
-     */
-    static int getPerformancePitchFromRG21Pitch(int heightOnStaff,
-                                                const Accidental &accidental,
-                                                const Clef &clef,
-                                                const Key &key);
-
-    /**
-     * return the result of transposing the given pitch by the
-     * specified interval in the given key. The key is left unchanged,
-     * only the pitch is transposed.
-     */
-    Pitch transpose(const Key &key, int pitchDelta, int heightDelta) const;
-
-    /**
-      * checks whether the accidental specified for this pitch (if any)
-      * is valid - for example, a Sharp for pitch 11 is invalid, as
-      * it's between A# and B#.
-      */
-    bool validAccidental() const;
-
-    /**
-     * Returned event is on heap; caller takes responsibility for ownership
-     */
-    Event *getAsNoteEvent(timeT absoluteTime, timeT duration) const;
-
-    /**
-     * Get the major key that has this Pitch as the tonic
-     */
-    Key getAsKey() const;
-
-    /**
-     * Get the major or minor key that has this Pitch as the tonic
-     */
-    Key getAsKey(bool isMinor) const;
-
-private:
-    int m_pitch;
-    Accidental m_accidental;
-
-    static void rawPitchToDisplayPitch
-    (int, const Clef &, const Key &, int &, Accidental &,
-    Accidentals::NoAccidentalStrategy);
-
-    static void displayPitchToRawPitch
-    (int, Accidental, const Clef &, const Key &,
-     int &, bool ignoreOffset = false);
-};
-
-
-
 /**
  * The Note class represents note durations only, not pitch or
  * accidental; it's therefore just as relevant to rest events as to
@@ -1085,7 +819,7 @@ public:
      * durational; they don't represent pitch, and may be as
      * relevant to rests as actual notes.
      */
-    Note(Type type, int dots = 0) :
+    explicit Note(Type type, int dots = 0) :
         m_type(type < Shortest ? Shortest :
                type >  Longest ?  Longest :
                type),
