@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -40,16 +40,15 @@ public:
     typedef PropertyDefnNotDefined basic_type;
 
     static std::string typeName() { return "Undefined"; }
-    static basic_type parse(std::string);
+    static basic_type parse(const std::string&);
     static std::string unparse(basic_type);
 };
 
 template <PropertyType P>
 typename PropertyDefn<P>::basic_type
-PropertyDefn<P>::parse(std::string)
+PropertyDefn<P>::parse(const std::string&)
 {
     throw(0);
-    return "";
 }
 
 template <PropertyType P>
@@ -57,7 +56,6 @@ std::string
 PropertyDefn<P>::unparse(typename PropertyDefn<P>::basic_type)
 {
     throw(0);
-    return "";
 }
 
 
@@ -68,7 +66,7 @@ public:
     typedef long basic_type;
 
     static std::string typeName();
-    static basic_type parse(std::string s);
+    static basic_type parse(const std::string& s);
     static std::string unparse(basic_type i);
 };
 
@@ -80,7 +78,7 @@ public:
     typedef std::string basic_type;
 
     static std::string typeName();
-    static basic_type parse(std::string s);
+    static basic_type parse(const std::string& s);
     static std::string unparse(basic_type i);
 };
 
@@ -91,7 +89,7 @@ public:
     typedef bool basic_type;
 
     static std::string typeName();
-    static basic_type parse(std::string s);
+    static basic_type parse(const std::string& s);
     static std::string unparse(basic_type i);
 };
 
@@ -102,7 +100,7 @@ public:
     typedef RealTime basic_type;
 
     static std::string typeName();
-    static basic_type parse(std::string s);
+    static basic_type parse(const std::string& s);
     static std::string unparse(basic_type i);
 };
 
@@ -126,7 +124,7 @@ public:
 };
 
 #ifndef NDEBUG
-inline std::ostream& operator<<(std::ostream &out, PropertyStoreBase &e)
+inline std::ostream& operator<<(std::ostream &out, const PropertyStoreBase &e)
 { e.dump(out); return out; }
 #endif
 
