@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -169,7 +169,7 @@ Segment::~Segment()
     if (!m_observers.empty()) {
         RG_WARNING << "dtor: Warning: " << m_observers.size() << " observers still extant";
         RG_WARNING << "Observers are:";
-        for (ObserverSet::const_iterator i = m_observers.begin();
+        for (ObserverList::const_iterator i = m_observers.begin();
              i != m_observers.end(); ++i) {
             RG_WARNING << " " << (void *)(*i) << " [" << typeid(**i).name() << "]";
         }
@@ -291,7 +291,7 @@ bool
 Segment::isLinkedTo(Segment * seg) const {
     if (!m_segmentLinker) return false;
 
-    SegmentLinker * otherSegmentLinker = seg->getLinker();
+    const SegmentLinker * otherSegmentLinker = seg->getLinker();
     if (!otherSegmentLinker) return false;
 
     return m_segmentLinker == otherSegmentLinker;
@@ -460,7 +460,7 @@ Segment::setStartTime(timeT t)
     }
 
     // Handle updates and notifications just once.
-    for (ObserverSet::const_iterator i = m_observers.begin();
+    for (ObserverList::const_iterator i = m_observers.begin();
          i != m_observers.end(); ++i) {
         (*i)->allEventsChanged(this);
     }
@@ -672,8 +672,8 @@ Segment::erase(iterator pos)
 void
 Segment::erase(iterator from, iterator to)
 {
-    timeT startTime = 0, endTime = m_endTime;
-    if (from != end()) startTime = (*from)->getAbsoluteTime();
+    timeT startTimeOuter = 0, endTime = m_endTime;
+    if (from != end()) startTimeOuter = (*from)->getAbsoluteTime();
     if (to != end()) endTime = (*to)->getAbsoluteTime() + (*to)->getGreaterDuration();
 
     // Not very efficient, but without an observer event for
@@ -694,10 +694,10 @@ Segment::erase(iterator from, iterator to)
         i = j;
     }
 
-    if (startTime == m_startTime && begin() != end()) {
-        timeT startTime = (*begin())->getAbsoluteTime();
-        if (m_composition) m_composition->setSegmentStartTime(this, startTime);
-        else m_startTime = startTime;
+    if (startTimeOuter == m_startTime  &&  begin() != end()) {
+        const timeT startTimeInner = (*begin())->getAbsoluteTime();
+        if (m_composition) m_composition->setSegmentStartTime(this, startTimeInner);
+        else m_startTime = startTimeInner;
         notifyStartChanged(m_startTime);
     }
 
@@ -705,7 +705,7 @@ Segment::erase(iterator from, iterator to)
         updateEndTime();
     }
 
-    updateRefreshStatuses(startTime, endTime);
+    updateRefreshStatuses(startTimeOuter, endTime);
 }
 
 
@@ -844,7 +844,7 @@ Segment::normalizeRests(timeT startTime, timeT endTime)
     // the start and end times, consider separately each of the sections
     // they divide the range up into.
 
-    Composition *composition = getComposition();
+    const Composition *composition = getComposition();
     if (composition) {
         int timeSigNo = composition->getTimeSignatureNumberAt(startTime);
         if (timeSigNo < composition->getTimeSignatureCount() - 1) {
@@ -1477,7 +1477,7 @@ Segment::notifyAdd(Event *e) const
     Profiler profiler("Segment::notifyAdd()");
     checkInsertAsClefKey(e);
 
-    for (ObserverSet::const_iterator i = m_observers.begin();
+    for (ObserverList::const_iterator i = m_observers.begin();
          i != m_observers.end(); ++i) {
         (*i)->eventAdded(this, e);
     }
@@ -1500,7 +1500,7 @@ Segment::notifyRemove(Event *e) const
         }
     }
 
-    for (ObserverSet::const_iterator i = m_observers.begin();
+    for (ObserverList::const_iterator i = m_observers.begin();
          i != m_observers.end(); ++i) {
         (*i)->eventRemoved(this, e);
     }
@@ -1510,7 +1510,7 @@ Segment::notifyRemove(Event *e) const
 void
 Segment::notifyAppearanceChange() const
 {
-    for (ObserverSet::const_iterator i = m_observers.begin();
+    for (ObserverList::const_iterator i = m_observers.begin();
          i != m_observers.end(); ++i) {
         (*i)->appearanceChanged(this);
     }
@@ -1522,7 +1522,7 @@ Segment::notifyStartChanged(timeT newTime)
     Profiler profiler("Segment::notifyStartChanged()");
     if (m_notifyResizeLocked) return;
 
-    for (ObserverSet::const_iterator i = m_observers.begin();
+    for (ObserverList::const_iterator i = m_observers.begin();
          i != m_observers.end(); ++i) {
         (*i)->startChanged(this, newTime);
     }
@@ -1540,7 +1540,7 @@ Segment::notifyEndMarkerChange(bool shorten)
 
     if (m_notifyResizeLocked) return;
 
-    for (ObserverSet::const_iterator i = m_observers.begin();
+    for (ObserverList::const_iterator i = m_observers.begin();
          i != m_observers.end(); ++i) {
         (*i)->endMarkerTimeChanged(this, shorten);
     }
@@ -1553,7 +1553,7 @@ Segment::notifyEndMarkerChange(bool shorten)
 void
 Segment::notifyTransposeChange()
 {
-    for (ObserverSet::const_iterator i = m_observers.begin();
+    for (ObserverList::const_iterator i = m_observers.begin();
          i != m_observers.end(); ++i) {
         (*i)->transposeChanged(this, m_transpose);
     }
@@ -1563,7 +1563,7 @@ Segment::notifyTransposeChange()
 void
 Segment::notifySourceDeletion() const
 {
-    for (ObserverSet::const_iterator i = m_observers.begin();
+    for (ObserverList::const_iterator i = m_observers.begin();
          i != m_observers.end(); ++i) {
         (*i)->segmentDeleted(this);
     }
@@ -1754,11 +1754,11 @@ void
 Segment::dumpObservers()
 {
     RG_DEBUG << "Observers of segment " << this << " are:";
-     for (ObserverSet::const_iterator i = m_observers.begin();
+     for (ObserverList::const_iterator i = m_observers.begin();
           i != m_observers.end(); ++i) {
         RG_DEBUG << "  " << (*i);
     }
-    for (ObserverSet::const_iterator i = m_observers.begin();
+    for (ObserverList::const_iterator i = m_observers.begin();
           i != m_observers.end(); ++i) {
         Segment *seg = dynamic_cast<Segment *>(*i);
         if (seg)
