@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -19,6 +19,7 @@
 
 #include "SegmentNotationHelper.h"
 #include "base/NotationTypes.h"
+#include "base/Pitch.h"
 #include "Quantizer.h"
 #include "BasicQuantizer.h"
 #include "NotationQuantizer.h"
@@ -30,12 +31,15 @@
 #include <iterator>
 #include <list>
 
+using std::string;
+using std::list;
+
 //#define DEBUG_DECOUNTERPOINT
 
+
 namespace Rosegarden
 {
-using std::string;
-using std::list;
+
 
 using namespace BaseProperties;
 
@@ -61,7 +65,7 @@ SegmentNotationHelper::notationQuantizer() {
 Segment::iterator
 SegmentNotationHelper::findNotationAbsoluteTime(timeT t)
 {
-    iterator i(segment().findTime(t));
+    Segment::iterator i(segment().findTime(t));
 
     // We don't know whether the notation absolute time t will appear
     // before or after the real absolute time t.  First scan backwards
@@ -164,18 +168,18 @@ SegmentNotationHelper::setNotationProperties(timeT startTime, timeT endTime)
 }
 
 timeT
-SegmentNotationHelper::getNotationEndTime(Event *e)
+SegmentNotationHelper::getNotationEndTime(const Event *e)
 {
     return e->getNotationAbsoluteTime() + e->getNotationDuration();
 }
 
 
 Segment::iterator
-SegmentNotationHelper::getNextAdjacentNote(iterator i,
+SegmentNotationHelper::getNextAdjacentNote(Segment::iterator i,
                                            bool matchPitch,
                                            bool allowOverlap)
 {
-    iterator j(i);
+    Segment::iterator j(i);
     if (!isBeforeEndMarker(i)) return i;
     if (!(*i)->isa(Note::EventType)) return end();
 
@@ -201,18 +205,22 @@ SegmentNotationHelper::getNextAdjacentNote(iterator i,
         bool isGrace = (*i)->has(IS_GRACE_NOTE) &&
             (*i)->get<Bool>(IS_GRACE_NOTE);
         RG_DEBUG << "getNextAdjacentNote isGrace" << isGrace;
-        if (isGrace && jStart < iEnd) return j;
+
+        // At this point we know jStart < iEnd.  There was a check for
+        // that here.  It is not needed.
+
+        if (isGrace) return j;
     }
 }
 
 
 Segment::iterator
-SegmentNotationHelper::getPreviousAdjacentNote(iterator i,
+SegmentNotationHelper::getPreviousAdjacentNote(Segment::iterator i,
                                                timeT rangeStart,
                                                bool matchPitch,
                                                bool allowOverlap)
 {
-    iterator j(i);
+    Segment::iterator j(i);
     if (!isBeforeEndMarker(i)) return i;
     if (!(*i)->isa(Note::EventType)) return end();
 
@@ -242,7 +250,7 @@ SegmentNotationHelper::getPreviousAdjacentNote(iterator i,
 
 
 Segment::iterator
-SegmentNotationHelper::findContiguousNext(iterator el)
+SegmentNotationHelper::findContiguousNext(Segment::iterator el)
 {
     std::string elType = (*el)->getType(),
         reject, accept;
@@ -260,7 +268,7 @@ SegmentNotationHelper::findContiguousNext(iterator el)
 
     bool success = false;
 
-    iterator i = ++el;
+    Segment::iterator i = ++el;
 
     for(; isBeforeEndMarker(i); ++i) {
         std::string iType = (*i)->getType();
@@ -281,7 +289,7 @@ SegmentNotationHelper::findContiguousNext(iterator el)
 }
 
 Segment::iterator
-SegmentNotationHelper::findContiguousPrevious(iterator el)
+SegmentNotationHelper::findContiguousPrevious(Segment::iterator el)
 {
     if (el == begin()) return end();
 
@@ -301,7 +309,7 @@ SegmentNotationHelper::findContiguousPrevious(iterator el)
 
     bool success = false;
 
-    iterator i = --el;
+    Segment::iterator i = --el;
 
     while (true) {
         std::string iType = (*i)->getType();
@@ -326,10 +334,10 @@ SegmentNotationHelper::findContiguousPrevious(iterator el)
 bool
 SegmentNotationHelper::noteIsInChord(Event *note)
 {
-    iterator i = segment().findSingle(note);
+    Segment::iterator i = segment().findSingle(note);
     timeT t = note->getNotationAbsoluteTime();
 
-    for (iterator j = i; j != end(); ++j) { // not isBeforeEndMarker, unnecessary here
+    for (Segment::iterator j = i; j != end(); ++j) { // not isBeforeEndMarker, unnecessary here
         if (j == i) continue;
         if ((*j)->isa(Note::EventType)) {
             timeT tj = (*j)->getNotationAbsoluteTime();
@@ -338,7 +346,7 @@ SegmentNotationHelper::noteIsInChord(Event *note)
         }
     }
 
-    for (iterator j = i; ; ) {
+    for (Segment::iterator j = i; ; ) {
         if (j == begin()) break;
         --j;
         if ((*j)->isa(Note::EventType)) {
@@ -416,13 +424,13 @@ SegmentNotationHelper::getNoteTiedWith(Event *note, bool forwards)
 bool
 SegmentNotationHelper::collapseRestsIfValid(Event* e, bool& collapseForward)
 {
-    iterator elPos = segment().findSingle(e);
+    Segment::iterator elPos = segment().findSingle(e);
     if (elPos == end()) return false;
 
     timeT myDuration = (*elPos)->getNotationDuration();
 
     // findContiguousNext won't return an iterator beyond the end marker
-    iterator nextEvent = findContiguousNext(elPos),
+    Segment::iterator nextEvent = findContiguousNext(elPos),
          previousEvent = findContiguousPrevious(elPos);
 
     // Remark: findContiguousXXX is inadequate for notes, we would
@@ -485,16 +493,16 @@ SegmentNotationHelper::isSplitValid(timeT a, timeT b)
 }
 
 Segment::iterator
-SegmentNotationHelper::splitIntoTie(iterator &i, timeT baseDuration)
+SegmentNotationHelper::splitIntoTie(Segment::iterator &i, timeT baseDuration)
 {
     if (i == end()) return end();
-    iterator i2;
+    Segment::iterator i2;
     segment().getTimeSlice((*i)->getAbsoluteTime(), i, i2);
     return splitIntoTie(i, i2, baseDuration);
 }
 
 Segment::iterator
-SegmentNotationHelper::splitIntoTie(iterator &from, iterator to,
+SegmentNotationHelper::splitIntoTie(Segment::iterator &from, Segment::iterator to,
                                     timeT baseDuration)
 {
     // so long as we do the quantization checks for validity before
@@ -510,18 +518,18 @@ SegmentNotationHelper::splitIntoTie(iterator &from, iterator to,
     (*from)->get<Int>(BEAMED_GROUP_ID, firstGroupId);
 
     long nextGroupId = -1;
-    iterator ni(to);
+    Segment::iterator ni(to);
 
     if (segment().isBeforeEndMarker(ni) && segment().isBeforeEndMarker(++ni)) {
         (*ni)->get<Int>(BEAMED_GROUP_ID, nextGroupId);
     }
 
     list<Event *> toInsert;
-    list<iterator> toErase;
+    list<Segment::iterator> toErase;
 
     // Split all the note and rest events in range [from, to[
     //
-    for (iterator i = from; i != to; ++i) {
+    for (Segment::iterator i = from; i != to; ++i) {
 
         if (!(*i)->isa(Note::EventType) &&
             !(*i)->isa(Note::EventRestType)) continue;
@@ -593,13 +601,13 @@ SegmentNotationHelper::splitIntoTie(iterator &from, iterator to,
     }
 
     // erase the old events
-    for (list<iterator>::iterator i = toErase.begin();
+    for (list<Segment::iterator>::iterator i = toErase.begin();
          i != toErase.end(); ++i) {
         segment().erase(*i);
     }
 
     from = end();
-    iterator last = end();
+    Segment::iterator last = end();
 
     // now insert the new events
     for (list<Event *>::iterator i = toInsert.begin();
@@ -642,7 +650,7 @@ SegmentNotationHelper::isViable(timeT duration, int dots)
 
 
 void
-SegmentNotationHelper::makeRestViable(iterator i)
+SegmentNotationHelper::makeRestViable(Segment::iterator i)
 {
     timeT absTime = (*i)->getAbsoluteTime();
     timeT duration = (*i)->getDuration();
@@ -652,7 +660,7 @@ SegmentNotationHelper::makeRestViable(iterator i)
 
 
 Event *
-SegmentNotationHelper::makeThisNoteViable(iterator noteItr, bool splitAtBars)
+SegmentNotationHelper::makeThisNoteViable(Segment::iterator noteItr, bool splitAtBars)
 {
     // We don't use quantized values here; we want a precise division.
     // Even if it doesn't look precise on the score (because the score
@@ -724,7 +732,6 @@ SegmentNotationHelper::makeThisNoteViable(iterator noteItr, bool splitAtBars)
         return *noteItr;
     }
 
-    acc = (*i)->getNotationAbsoluteTime();
     Event *e = new Event(*(*i));
 
     bool lastTiedForward = false;
@@ -793,8 +800,6 @@ SegmentNotationHelper::makeThisNoteViable(iterator noteItr, bool splitAtBars)
         delete e;
         e = splits.second;
 
-        acc += *dli;
-
         e->set<Bool>(TIED_BACKWARD, true);
     }
 
@@ -812,7 +817,7 @@ SegmentNotationHelper::makeThisNoteViable(iterator noteItr, bool splitAtBars)
 }
 
 void
-SegmentNotationHelper::makeNotesViable(iterator from, iterator to,
+SegmentNotationHelper::makeNotesViable(Segment::iterator from, Segment::iterator to,
                                        bool splitAtBars)
 {
 //  std::vector<Event *> toInsert;
@@ -849,7 +854,7 @@ SegmentNotationHelper::insertNote(timeT absoluteTime, Note note, int pitch,
     Event *e = new Event(Note::EventType, absoluteTime, note.getDuration());
     e->set<Int>(PITCH, pitch);
     e->set<String>(ACCIDENTAL, explicitAccidental);
-    iterator i = insertNote(e);
+    Segment::iterator i = insertNote(e);
     delete e;
     return i;
 }
@@ -861,7 +866,7 @@ SegmentNotationHelper::insertNote(Event *modelEvent)
     RG_DEBUG << *modelEvent;
 
     timeT absoluteTime = modelEvent->getAbsoluteTime();
-    iterator i = segment().findNearestTime(absoluteTime);
+    Segment::iterator i = segment().findNearestTime(absoluteTime);
 
     RG_DEBUG << "absoluteTime" << absoluteTime;
 
@@ -878,7 +883,7 @@ SegmentNotationHelper::insertNote(Event *modelEvent)
 
     timeT duration = modelEvent->getDuration();
 
-    iterator j = i;
+    Segment::iterator j = i;
     while (j != end()) {
         // ignore non note/rest
         bool noteOrRest = (*j)->isa(Note::EventType) ||
@@ -904,7 +909,7 @@ SegmentNotationHelper::insertNote(Event *modelEvent)
 Segment::iterator
 SegmentNotationHelper::insertRest(timeT absoluteTime, Note note)
 {
-    iterator i, j;
+    Segment::iterator i, j;
     segment().getTimeSlice(absoluteTime, i, j);
 
     //!!! Deal with end-of-bar issues!
@@ -930,7 +935,7 @@ SegmentNotationHelper::insertRest(timeT absoluteTime, Note note)
 // iterator (which will have been replaced)
 
 Segment::iterator
-SegmentNotationHelper::collapseRestsForInsert(iterator firstRest,
+SegmentNotationHelper::collapseRestsForInsert(Segment::iterator firstRest,
                                               timeT desiredDuration)
 {
     // collapse at most once, then recurse
@@ -939,11 +944,11 @@ SegmentNotationHelper::collapseRestsForInsert(iterator firstRest,
         !(*firstRest)->isa(Note::EventRestType)) return firstRest;
 
     timeT d = (*firstRest)->getDuration();
-    iterator j = findContiguousNext(firstRest); // won't return itr after end marker
+    Segment::iterator j = findContiguousNext(firstRest); // won't return itr after end marker
     if (d >= desiredDuration || j == end()) return firstRest;
 
     Event *e(new Event(**firstRest, (*firstRest)->getAbsoluteTime(), d + (*j)->getDuration()));
-    iterator ii(insert(e));
+    Segment::iterator ii(insert(e));
     erase(firstRest);
     erase(j);
 
@@ -952,7 +957,7 @@ SegmentNotationHelper::collapseRestsForInsert(iterator firstRest,
 
 
 Segment::iterator
-SegmentNotationHelper::insertSomething(iterator i, int duration,
+SegmentNotationHelper::insertSomething(Segment::iterator i, int duration,
                                        Event *modelEvent, bool tiedBack)
 {
     // Rules:
@@ -1026,7 +1031,7 @@ SegmentNotationHelper::insertSomething(iterator i, int duration,
         } else if ((*i)->isa(Note::EventRestType)) {
 
 //            RG_DEBUG << "Found rest, splitting";
-            iterator last = splitIntoTie(i, duration);
+            Segment::iterator last = splitIntoTie(i, duration);
 
             // Recover viability for the second half of any split rest
             // (we duck out of this if we find we're in a tupleted zone)
@@ -1051,7 +1056,7 @@ SegmentNotationHelper::insertSomething(iterator i, int duration,
         // of the segment
 
         if ((*i)->isa(Note::EventRestType)) {
-            iterator j;
+            Segment::iterator j;
             for (j = i; j != end(); ++j) {
                 if ((*j)->isa(Note::EventType)) break;
             }
@@ -1092,25 +1097,27 @@ SegmentNotationHelper::insertSomething(iterator i, int duration,
 }
 
 Segment::iterator
-SegmentNotationHelper::insertSingleSomething(iterator i, int duration,
-                                             Event *modelEvent, bool tiedBack)
+SegmentNotationHelper::insertSingleSomething(Segment::iterator i,
+                                             int duration,
+                                             const Event *modelEvent,
+                                             bool tiedBack)
 {
-    timeT time;
+    timeT newEventTime;
     timeT notationTime;
     bool eraseI = false;
     timeT effectiveDuration(duration);
 
     if (i == end()) {
-        time = segment().getEndTime();
-        notationTime = time;
+        newEventTime = segment().getEndTime();
+        notationTime = newEventTime;
     } else {
-        time = (*i)->getAbsoluteTime();
+        newEventTime = (*i)->getAbsoluteTime();
         notationTime = (*i)->getNotationAbsoluteTime();
         if (modelEvent->isa(Note::EventRestType) ||
             (*i)->isa(Note::EventRestType)) eraseI = true;
     }
 
-    Event *e = new Event(*modelEvent, time, effectiveDuration,
+    Event *e = new Event(*modelEvent, newEventTime, effectiveDuration,
                          modelEvent->getSubOrdering(), notationTime);
 
     // If the model event already has group info, I guess we'd better use it!
@@ -1125,10 +1132,10 @@ SegmentNotationHelper::insertSingleSomething(iterator i, int duration,
     if (eraseI) {
         // erase i and all subsequent events with the same type and
         // absolute time
-        timeT time((*i)->getAbsoluteTime());
+        const timeT timeToErase((*i)->getAbsoluteTime());
         std::string type((*i)->getType());
-        iterator j(i);
-        while (j != end() && (*j)->getAbsoluteTime() == time) {
+        Segment::iterator j(i);
+        while (j != end() && (*j)->getAbsoluteTime() == timeToErase) {
             ++j;
             if ((*i)->isa(type)) erase(i);
             i = j;
@@ -1139,7 +1146,7 @@ SegmentNotationHelper::insertSingleSomething(iterator i, int duration,
 }
 
 void
-SegmentNotationHelper::setInsertedNoteGroup(Event *e, iterator i)
+SegmentNotationHelper::setInsertedNoteGroup(Event *e, Segment::iterator i)
 {
     // Formerly this was posited on the note being inserted between
     // two notes in the same group, but that's quite wrong-headed: we
@@ -1224,12 +1231,12 @@ SegmentNotationHelper::insertText(timeT absoluteTime, const Text& text)
 void
 SegmentNotationHelper::deleteNote(Event *e, bool collapseRest)
 {
-    iterator i = segment().findSingle(e);
+    Segment::iterator i = segment().findSingle(e);
 
     if (i == end()) return;
 
     if ((*i)->has(TIED_BACKWARD) && (*i)->get<Bool>(TIED_BACKWARD)) {
-        iterator j = getPreviousAdjacentNote(i, segment().getStartTime(),
+        Segment::iterator j = getPreviousAdjacentNote(i, segment().getStartTime(),
                                              true, false);
         if (j != end()) {
             (*j)->unset(TIED_FORWARD); // don't even check if it has it set
@@ -1237,7 +1244,7 @@ SegmentNotationHelper::deleteNote(Event *e, bool collapseRest)
     }
 
     if ((*i)->has(TIED_FORWARD) && (*i)->get<Bool>(TIED_FORWARD)) {
-        iterator j = getNextAdjacentNote(i, true, false);
+        Segment::iterator j = getNextAdjacentNote(i, true, false);
         if (j != end()) {
             (*j)->unset(TIED_BACKWARD); // don't even check if it has it set
         }
@@ -1251,7 +1258,7 @@ SegmentNotationHelper::deleteNote(Event *e, bool collapseRest)
     // another note starts before this one, overlaps it, but then also
     // ends before it does -- but I think we can live with that.
 
-    iterator j = i;
+    Segment::iterator j = i;
     timeT dur = (*i)->getGreaterDuration();
     timeT endTime = (*i)->getAbsoluteTime() + dur;
 
@@ -1295,11 +1302,10 @@ SegmentNotationHelper::deleteNote(Event *e, bool collapseRest)
 
     }else{
         int untupled = e->get<Int>(BEAMED_GROUP_UNTUPLED_COUNT);
-        iterator begin, end;
+        Segment::iterator begin, end;
         int count = findBorderTuplet(i, begin, end);
         if (count>1){
             // insert rest instead of note
-            string type = (*i)->getType();
             int note_type = (*i)->get<Int>(NOTE_TYPE);
             insertRest((*i)->getAbsoluteTime(), Note(note_type,0));
         }else {
@@ -1347,7 +1353,7 @@ SegmentNotationHelper::deleteEvent(Event *e, bool collapseRest)
     else if (e->isa(Note::EventRestType)) res = deleteRest(e);
     else {
         // just plain delete
-        iterator i = segment().findSingle(e);
+        Segment::iterator i = segment().findSingle(e);
         if (i != end()) erase(i);
     }
 
@@ -1356,12 +1362,12 @@ SegmentNotationHelper::deleteEvent(Event *e, bool collapseRest)
 
 
 bool
-SegmentNotationHelper::hasEffectiveDuration(iterator i)
+SegmentNotationHelper::hasEffectiveDuration(Segment::iterator i)
 {
     bool hasDuration = ((*i)->getDuration() > 0);
 
     if ((*i)->isa(Note::EventType)) {
-        iterator i0(i);
+        Segment::iterator i0(i);
         if (++i0 != end() &&
             (*i0)->isa(Note::EventType) &&
             (*i0)->getNotationAbsoluteTime() ==
@@ -1376,14 +1382,14 @@ SegmentNotationHelper::hasEffectiveDuration(iterator i)
 
 
 void
-SegmentNotationHelper::makeBeamedGroup(timeT from, timeT to, string type)
+SegmentNotationHelper::makeBeamedGroup(timeT from, timeT to, const string& type)
 {
     makeBeamedGroupAux(segment().findTime(from), segment().findTime(to),
                        type, false);
 }
 
 void
-SegmentNotationHelper::makeBeamedGroup(iterator from, iterator to, string type)
+SegmentNotationHelper::makeBeamedGroup(Segment::iterator from, Segment::iterator to, const string& type)
 {
     makeBeamedGroupAux
       ((from == end()) ? from : segment().findTime((*from)->getAbsoluteTime()),
@@ -1392,13 +1398,13 @@ SegmentNotationHelper::makeBeamedGroup(iterator from, iterator to, string type)
 }
 
 void
-SegmentNotationHelper::makeBeamedGroupExact(iterator from, iterator to, string type)
+SegmentNotationHelper::makeBeamedGroupExact(Segment::iterator from, Segment::iterator to, const string& type)
 {
     makeBeamedGroupAux(from, to, type, true);
 }
 
 void
-SegmentNotationHelper::makeBeamedGroupAux(iterator from, iterator to,
+SegmentNotationHelper::makeBeamedGroupAux(Segment::iterator from, Segment::iterator to,
                                           string type, bool groupGraces)
 {
 //    RG_DEBUG << "SegmentNotationHelper::makeBeamedGroupAux: type " << type;
@@ -1407,7 +1413,7 @@ SegmentNotationHelper::makeBeamedGroupAux(iterator from, iterator to,
     int groupId = segment().getNextId();
     bool beamedSomething = false;
 
-    for (iterator i = from; i != to; ++i) {
+    for (Segment::iterator i = from; i != to; ++i) {
 //        RG_DEBUG << "looking at " << (*i)->getType() << " at " << (*i)->getAbsoluteTime();
 
         // don't permit ourselves to change the type of an
@@ -1432,7 +1438,7 @@ SegmentNotationHelper::makeBeamedGroupAux(iterator from, iterator to,
             (*i)->getNotationDuration() >= Note(Note::Crotchet).getDuration()) {
 //            RG_DEBUG << "too long";
             if (!beamedSomething) continue;
-            iterator j = i;
+            Segment::iterator j = i;
             bool somethingLeft = false;
             while (++j != to) {
                 if ((*j)->getType() == Note::EventType &&
@@ -1460,12 +1466,12 @@ SegmentNotationHelper::makeTupletGroup(timeT t, int untupled, int tupled,
     RG_DEBUG << "SegmentNotationHelper::makeTupletGroup: time " << t << ", unit "<< unit << ", params " << untupled << "/" << tupled << ", id " << groupId;
 
     list<Event *> toInsert;
-    list<iterator> toErase;
+    list<Segment::iterator> toErase;
     timeT notationTime = t;
     timeT fillWithRestsTo = t;
     bool haveStartNotationTime = false;
 
-    for (iterator i = segment().findTime(t); i != end(); ++i) {
+    for (Segment::iterator i = segment().findTime(t); i != end(); ++i) {
 
         // skip anything that is not a note or a rest
         bool noteOrRest = (*i)->isa(Note::EventType) ||
@@ -1515,7 +1521,7 @@ SegmentNotationHelper::makeTupletGroup(timeT t, int untupled, int tupled,
         toErase.push_back(i);
         // At the end of a segment we may run out of events before the
         // tuplet is complete. So complete it here
-        iterator j = i;
+        Segment::iterator j = i;
         ++j;
         if (j == end()) {
             // yes i is the last event
@@ -1536,7 +1542,7 @@ SegmentNotationHelper::makeTupletGroup(timeT t, int untupled, int tupled,
         }
     }
 
-    for (list<iterator>::iterator i = toErase.begin();
+    for (list<Segment::iterator>::iterator i = toErase.begin();
          i != toErase.end(); ++i) {
         segment().erase(*i);
     }
@@ -1564,7 +1570,7 @@ SegmentNotationHelper::unbeam(timeT from, timeT to)
 }
 
 void
-SegmentNotationHelper::unbeam(iterator from, iterator to)
+SegmentNotationHelper::unbeam(Segment::iterator from, Segment::iterator to)
 {
     unbeamAux
      ((from == end()) ? from : segment().findTime((*from)->getAbsoluteTime()),
@@ -1572,9 +1578,9 @@ SegmentNotationHelper::unbeam(iterator from, iterator to)
 }
 
 void
-SegmentNotationHelper::unbeamAux(iterator from, iterator to)
+SegmentNotationHelper::unbeamAux(Segment::iterator from, Segment::iterator to)
 {
-    for (iterator i = from; i != to; ++i) {
+    for (Segment::iterator i = from; i != to; ++i) {
         (*i)->unset(BEAMED_GROUP_ID);
         (*i)->unset(BEAMED_GROUP_TYPE);
         (*i)->clearNonPersistentProperties();
@@ -1591,7 +1597,7 @@ SegmentNotationHelper::unbeamAux(iterator from, iterator to)
 */
 
 void
-SegmentNotationHelper::autoBeam(timeT from, timeT to, string type)
+SegmentNotationHelper::autoBeam(timeT from, timeT to, const string& type)
 {
     /*
     RG_DEBUG << "autoBeam from " << from << " to " << to << " on segment start time " << segment().getStartTime() << ", end time " << segment().getEndTime() << ", end marker " << segment().getEndMarkerTime();
@@ -1601,7 +1607,9 @@ SegmentNotationHelper::autoBeam(timeT from, timeT to, string type)
 }
 
 void
-SegmentNotationHelper::autoBeam(iterator from, iterator to, string type)
+SegmentNotationHelper::autoBeam(Segment::iterator from,
+                                Segment::iterator to,
+                                const string& type)
 {
     // This can only manage whole bars at a time, and it will split
     // the from-to range out to encompass the whole bars in which they
@@ -1616,7 +1624,7 @@ SegmentNotationHelper::autoBeam(iterator from, iterator to, string type)
 
     unbeam(from, to);
 
-    Composition *comp = segment().getComposition();
+    const Composition *comp = segment().getComposition();
 
     // Get bar range for selection.  Since this is inclusive, we subtract 1 from
     // the "to" time to ensure we don't get an additional bar (bug #703).
@@ -1629,8 +1637,8 @@ SegmentNotationHelper::autoBeam(iterator from, iterator to, string type)
     for (int barNo = fromBar; barNo <= toBar; ++barNo) {
 
         std::pair<timeT, timeT> barRange = comp->getBarRange(barNo);
-        iterator barStart = segment().findTime(barRange.first);
-        iterator barEnd   = segment().findTime(barRange.second);
+        Segment::iterator barStart = segment().findTime(barRange.first);
+        Segment::iterator barEnd   = segment().findTime(barRange.second);
 
         // Make sure we're examining the notes defined to be within
         // the bar in notation terms rather than raw terms
@@ -1638,7 +1646,7 @@ SegmentNotationHelper::autoBeam(iterator from, iterator to, string type)
         while (barStart != segment().end() &&
                (*barStart)->getNotationAbsoluteTime() < barRange.first) ++barStart;
 
-        iterator scooter = barStart;
+        Segment::iterator scooter = barStart;
         if (barStart != segment().end()) {
             while (scooter != segment().begin()) {
                 --scooter;
@@ -1681,8 +1689,10 @@ SegmentNotationHelper::autoBeam(iterator from, iterator to, string type)
 */
 
 void
-SegmentNotationHelper::autoBeamBar(iterator from, iterator to,
-                                   TimeSignature tsig, string type)
+SegmentNotationHelper::autoBeamBar(Segment::iterator from,
+                                   Segment::iterator to,
+                                   const TimeSignature& tsig,
+                                   const string& type)
 {
     int num = tsig.getNumerator();
     int denom = tsig.getDenominator();
@@ -1722,17 +1732,17 @@ SegmentNotationHelper::autoBeamBar(iterator from, iterator to,
 
 
 void
-SegmentNotationHelper::autoBeamBar(iterator from, iterator to,
+SegmentNotationHelper::autoBeamBar(Segment::iterator from, Segment::iterator to,
                                    timeT average, timeT minimum,
-                                   timeT maximum, string type)
+                                   timeT maximum, const string& type)
 {
     timeT accumulator = 0;
     timeT crotchet    = Note(Note::Crotchet).getDuration();
     timeT semiquaver  = Note(Note::Semiquaver).getDuration();
 
-    iterator e = end();
+    Segment::iterator e = end();
 
-    for (iterator i = from; i != to && i != e; ++i) {
+    for (Segment::iterator i = from; i != to && i != e; ++i) {
 
         // only look at one note in each chord, and at rests
         if (!hasEffectiveDuration(i)) continue;
@@ -1752,7 +1762,7 @@ SegmentNotationHelper::autoBeamBar(iterator from, iterator to,
 
             // I hope this is clear.
 
-            iterator k = end(); // best-so-far last item in group;
+            Segment::iterator k = end(); // best-so-far last item in group;
                                 // end() indicates that we've found nothing
 
             timeT tmin         = minimum;
@@ -1763,7 +1773,7 @@ SegmentNotationHelper::autoBeamBar(iterator from, iterator to,
             int beamable       = 0;
             int longerThanDemi = 0;
 
-            for (iterator j = i; j != to; ++j) {
+            for (Segment::iterator j = i; j != to; ++j) {
 
                 if (!hasEffectiveDuration(j)) continue;
                 timeT jdur = (*j)->getNotationDuration();
@@ -1796,7 +1806,7 @@ SegmentNotationHelper::autoBeamBar(iterator from, iterator to,
                 // happen unless we really are displaying completely
                 // unquantized data in which case anything goes.)
 
-                iterator jnext(j);
+                Segment::iterator jnext(j);
 
                 if ((count > maximum)
                     || (longerThanDemi > 4)
@@ -1808,7 +1818,7 @@ SegmentNotationHelper::autoBeamBar(iterator from, iterator to,
 
                     if (k != end() && beamable >= 2) {
 
-                        iterator knext(k);
+                        Segment::iterator knext(k);
                         ++knext;
 
                         makeBeamedGroup(i, knext, type);
@@ -1851,7 +1861,7 @@ SegmentNotationHelper::autoBeamBar(iterator from, iterator to,
 // based on X11 Rosegarden's GuessItemListClef in editor/src/MidiIn.c
 
 Clef
-SegmentNotationHelper::guessClef(iterator from, iterator to)
+SegmentNotationHelper::guessClef(Segment::iterator from, Segment::iterator to)
 {
     long totalHeight = 0;
     int noteCount = 0;
@@ -1860,7 +1870,7 @@ SegmentNotationHelper::guessClef(iterator from, iterator to)
     Clef clef;
     Key key;
 
-    for (iterator i = from; i != to; ++i) {
+    for (Segment::iterator i = from; i != to; ++i) {
         if ((*i)->isa(Note::EventType)) {
 //!!!            NotationDisplayPitch p((*i)->get<Int>(PITCH), clef, key);
             try {
@@ -1901,7 +1911,7 @@ SegmentNotationHelper::removeRests(timeT time, timeT &duration, bool testOnly)
     RG_DEBUG << "SegmentNotationHelper::removeRests(" << time
               << ", " << duration << ")";
 
-    iterator from = segment().lower_bound(&dummy);
+    Segment::iterator from = segment().lower_bound(&dummy);
 
     // ignore any number of zero-duration events at the start
     while (from != segment().end() &&
@@ -1909,7 +1919,7 @@ SegmentNotationHelper::removeRests(timeT time, timeT &duration, bool testOnly)
            (*from)->getDuration() == 0) ++from;
     if (from == segment().end()) return false;
 
-    iterator to = from;
+    Segment::iterator to = from;
 
     timeT eventTime = time;
     timeT finalTime = time + duration;
@@ -1939,7 +1949,7 @@ SegmentNotationHelper::removeRests(timeT time, timeT &duration, bool testOnly)
     }
 
     bool checkLastRest = false;
-    iterator lastEvent = to;
+    Segment::iterator lastEvent = to;
 
     if (eventTime < finalTime) {
         // shorten last event's duration, if possible
@@ -1990,24 +2000,24 @@ void
 SegmentNotationHelper::reorganizeRests(timeT startTime, timeT endTime,
                                        Reorganizer reorganizer)
 {
-    iterator ia = segment().findTime(startTime);
-    iterator ib = segment().findTime(endTime);
+    Segment::iterator ia = segment().findTime(startTime);
+    Segment::iterator ib = segment().findTime(endTime);
 
     if (ia == end()) return;
 
-    std::vector<iterator> erasable;
+    std::vector<Segment::iterator> erasable;
     std::vector<Event *> insertable;
 
 //    RG_DEBUG << "SegmentNotationHelper::reorganizeRests (" << startTime << ","
 //         << endTime << ")";
 
-    for (iterator i = ia; i != ib; ++i) {
+    for (Segment::iterator i = ia; i != ib; ++i) {
 
         if ((*i)->isa(Note::EventRestType)) {
 
             timeT startTime = (*i)->getAbsoluteTime();
             timeT duration = 0;
-            iterator j = i;
+            Segment::iterator j = i;
 
             for ( ; j != ib; ++j) {
 
@@ -2081,10 +2091,10 @@ Segment::iterator
 SegmentNotationHelper::collapseNoteAggressively(Event *note,
                                                 timeT rangeEnd)
 {
-    iterator i = segment().findSingle(note);
+    Segment::iterator i = segment().findSingle(note);
     if (i == end()) return end();
 
-    iterator j = getNextAdjacentNote(i, true, true);
+    Segment::iterator j = getNextAdjacentNote(i, true, true);
 
     if (j == end() || (*j)->getNotationAbsoluteTime() >= rangeEnd) return end();
     if ((*i)->maskedInTrigger() != (*j)->maskedInTrigger()) {
@@ -2118,7 +2128,7 @@ SegmentNotationHelper::collapseNoteAggressively(Event *note,
 }
 
 std::pair<Event *, Event *>
-SegmentNotationHelper::splitPreservingPerformanceTimes(Event *e, timeT q1)
+SegmentNotationHelper::splitPreservingPerformanceTimes(const Event *e, timeT q1)
 {
     timeT ut = e->getAbsoluteTime();
     timeT ud = e->getDuration();
@@ -2281,8 +2291,8 @@ SegmentNotationHelper::deCounterpoint(timeT startTime, timeT endTime)
 void
 SegmentNotationHelper::autoSlur(timeT startTime, timeT endTime, bool legatoOnly)
 {
-    iterator from = segment().findTime(startTime);
-    iterator to = segment().findTime(endTime);
+    Segment::iterator from = segment().findTime(startTime);
+    Segment::iterator to = segment().findTime(endTime);
 
     timeT potentialStart = segment().getEndTime();
     long  groupId = -1;
@@ -2290,7 +2300,7 @@ SegmentNotationHelper::autoSlur(timeT startTime, timeT endTime, bool legatoOnly)
     int   count = 0;
     bool  thisLegato = false, prevLegato = false;
 
-    for (iterator i = from; i != to && segment().isBeforeEndMarker(i); ++i) {
+    for (Segment::iterator i = from; i != to && segment().isBeforeEndMarker(i); ++i) {
 
         timeT t = (*i)->getNotationAbsoluteTime();
 
@@ -2315,7 +2325,7 @@ SegmentNotationHelper::autoSlur(timeT startTime, timeT endTime, bool legatoOnly)
             Indication ind(Indication::Slur, t - potentialStart);
             segment().insert(ind.getAsEvent(potentialStart));
             if (legatoOnly) {
-                for (iterator j = segment().findTime(potentialStart); j != i; ++j) {
+                for (Segment::iterator j = segment().findTime(potentialStart); j != i; ++j) {
                     Marks::removeMark(**j, Marks::Tenuto);
                 }
             }
@@ -2333,7 +2343,7 @@ SegmentNotationHelper::autoSlur(timeT startTime, timeT endTime, bool legatoOnly)
         Indication ind(Indication::Slur, endTime - potentialStart);
         segment().insert(ind.getAsEvent(potentialStart));
         if (legatoOnly) {
-            for (iterator j = segment().findTime(potentialStart);
+            for (Segment::iterator j = segment().findTime(potentialStart);
                  segment().isBeforeEndMarker(j) && j != to; ++j) {
                 Marks::removeMark(**j, Marks::Tenuto);
             }
@@ -2420,7 +2430,7 @@ void SegmentNotationHelper::updateIndications(timeT startTime, timeT endTime)
     // The slurMap now contains all (phrasing) slurs each with a list of notes.
 
     // For each slur in the slurMap, remove or adjust as appropriate.
-    for (SlurMap::value_type& pair : slurMap) {
+    for (const SlurMap::value_type& pair : slurMap) {
         Event* slurEvent = pair.first;
         const NoteList& noteList = pair.second;
 
@@ -2463,9 +2473,11 @@ void SegmentNotationHelper::updateIndications(timeT startTime, timeT endTime)
     }
 }
 
-int SegmentNotationHelper::findBorderTuplet(iterator it, iterator &start, iterator &end){
-    iterator beginB = segment().findTime(segment().getBarStartForTime((*it)->getAbsoluteTime()));
-    iterator endB = segment().findTime(segment().getBarEndForTime((*it)->getAbsoluteTime()));
+int SegmentNotationHelper::findBorderTuplet(
+        Segment::iterator it, Segment::iterator &start, Segment::iterator &end)
+{
+    Segment::iterator beginB = segment().findTime(segment().getBarStartForTime((*it)->getAbsoluteTime()));
+    Segment::iterator endB = segment().findTime(segment().getBarEndForTime((*it)->getAbsoluteTime()));
     int maxcount = 0;
     int count = 0;
     int index = 0;
@@ -2509,4 +2521,6 @@ int SegmentNotationHelper::findBorderTuplet(iterator it, iterator &start, iterat
     end=endB;
     return count;
 }
+
+
 } // end of namespace
