@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -337,8 +337,6 @@ SegmentFigData::SegmentFigData(Segment* s) :
             m_needsTag = true;
             m_type = Target;
         }
-
-        continue;
     }
 
     // We got to the end without finding anything figuration-relevant,
@@ -467,7 +465,7 @@ updateComposition(MacroCommand* command)
          i != segs.end();
          ++i) {
         Segment *s = i->first;
-        SegmentFigData &data = i->second;
+        const SegmentFigData &data = i->second;
 
         Q_ASSERT(!data.m_needsTag);
 
@@ -591,8 +589,8 @@ SegmentFigData::expand(SourcedFiguration& sourcedFiguration,
         (void)target->insert(e);
     }
     // Write the respective notes into target
-    RelativeEventVec & events = figuration->m_events;
-    for (RelativeEventVec::iterator k = events.begin();
+    const RelativeEventVec & events = figuration->m_events;
+    for (RelativeEventVec::const_iterator k = events.begin();
          k != events.end();
          ++k) {
         const timeT eventTime =
@@ -606,6 +604,7 @@ SegmentFigData::expand(SourcedFiguration& sourcedFiguration,
              ++j) {
             if ((eventTime >= j->m_start) &&
                 (eventTime < j->m_end))
+                // cppcheck-suppress useStlAlgorithm
                 {
                     pBlockChord = j->m_chord;
                     break;
