@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -133,7 +133,7 @@ NoteInsertionCommand::modifySegment()
             (Note::EventType,
              m_insertionTime,
              m_note.getDuration(),
-             0,
+             0,  // sub-ordering  ??? Event should handle this.
              m_insertionTime,
              m_note.getDuration());
 
@@ -277,7 +277,7 @@ NoteInsertionCommand::modifySegment()
         }
 
         if (m_matrixType) {
-            i = SegmentMatrixHelper(segment).insertNote(e);
+            i = SegmentMatrixHelper(segment).matrixInsertNote(e);
         } else {
             i = helper.insertNote(e);
             // e is just a model for SegmentNotationHelper::insertNote
