@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -19,16 +19,13 @@
 #include "AddTempoChangeCommand.h"
 
 #include "base/Composition.h"
+
 #include <QString>
 
 
 namespace Rosegarden
 {
 
-AddTempoChangeCommand::~AddTempoChangeCommand()
-{
-    // nothing here either
-}
 
 void
 AddTempoChangeCommand::execute()
@@ -56,4 +53,5 @@ AddTempoChangeCommand::unexecute()
     }
 }
 
+
 }
