@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -2374,7 +2374,7 @@ RoseXmlHandler::endElement(const QString& namespaceURI,
         // from "file" to "actual" IDs.  See discussion in
         // mapToActualInstrument() below.
 
-        for (Composition::trackcontainer::iterator i = comp.getTracks().begin();
+        for (Composition::TrackMap::iterator i = comp.getTracks().begin();
              i != comp.getTracks().end(); ++i) {
             InstrumentId iid = i->second->getInstrument();
             InstrumentId aid = mapToActualInstrument(iid);
