@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     This file is Copyright 2002
         Hans Kieserman      <hkieserman@mail.com>
@@ -34,6 +34,7 @@
 #include "base/Segment.h"
 #include "base/Selection.h"
 #include "document/io/LilyPondLanguage.h"
+
 #include <fstream>
 #include <set>
 #include <string>
@@ -53,21 +54,32 @@ namespace Rosegarden
 // This is now in the Rosegarden namespace so it can be used
 // in LilyPondOptionsDialog with the LilyVersionAwareCheckBox.
 enum {
-  LILYPOND_VERSION_2_12,
-  LILYPOND_VERSION_2_14,
-  LILYPOND_VERSION_2_16,
+  LILYPOND_VERSION_TOO_OLD,
   LILYPOND_VERSION_2_18,
-  LILYPOND_VERSION_2_19,
   LILYPOND_VERSION_2_20,
-  LILYPOND_VERSION_2_21,
   LILYPOND_VERSION_2_22,
-  LILYPOND_VERSION_2_23
+  LILYPOND_VERSION_2_24,
+  LILYPOND_VERSION_TOO_NEW
 };
 
+// Default version used if some error occurs
+const int LILYPOND_VERSION_DEFAULT = LILYPOND_VERSION_TOO_OLD + 1;
+
+// Versions strings associated with the previous enum.
+// They are used inside the LilyPond code.
+static const char* const LilyPond_Version_Strings[LILYPOND_VERSION_TOO_NEW + 1] = {
+    "old", "2.18.0", "2.20.0", "2.22.0", "2.24.0", "new"
+};
+
+// Versions names associated with the previous enum.
+// They are used in the GUI checkboxes.
+static const char* const LilyPond_Version_Names[LILYPOND_VERSION_TOO_NEW + 1] = {
+    "old", "2.18", "2.20", "2.22", "2.24", "new"
+};
+
+
 class TimeSignature;
 class Studio;
-class RosegardenMainWindow;
-class RosegardenMainViewWidget;
 class RosegardenDocument;
 class NotationView;
 class Key;
@@ -197,10 +209,10 @@ private:
                                    std::ofstream &str);
 
     std::pair<int,int> writeSkip(const TimeSignature &timeSig,
-				 timeT offset,
-				 timeT duration,
-				 bool useRests,
-				 std::ofstream &);
+                                 timeT offset,
+	                             timeT duration,
+                                 bool useRests,
+                                 std::ofstream &);
 
     /*
      * Handle LilyPond directive.  Returns true if the event was a directive,
