@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -45,14 +45,12 @@
 #include "commands/segment/SegmentSingleRepeatToCopyCommand.h"
 #include "document/CommandHistory.h"
 #include "document/RosegardenDocument.h"
-#include "RosegardenApplication.h"
 #include "gui/configuration/GeneralConfigurationPage.h"
 #include "gui/configuration/AudioConfigurationPage.h"
 #include "gui/dialogs/AudioSplitDialog.h"
 #include "gui/dialogs/AudioManagerDialog.h"
 #include "gui/dialogs/DocumentConfigureDialog.h"
-#include "gui/dialogs/TempoDialog.h"
-#include "gui/editors/eventlist/EventView.h"
+#include "gui/editors/eventlist/EventListEditor.h"
 #include "gui/editors/matrix/MatrixView.h"
 #include "gui/editors/notation/NotationView.h"
 #include "gui/editors/parameters/InstrumentParameterBox.h"
@@ -151,30 +149,6 @@ RosegardenMainViewWidget::RosegardenMainViewWidget(bool showTrackLabels,
             &CompositionView::editSegment,
             this, &RosegardenMainViewWidget::slotEditSegment);
 
-    //connect(m_trackEditor->getCompositionView(),
-    //        SIGNAL(editSegmentNotation(Segment *)),
-    //        SLOT(slotEditSegmentNotation(Segment *)));
-
-    //connect(m_trackEditor->getCompositionView(),
-    //        SIGNAL(editSegmentPitchView(Segment *)),
-    //        SLOT(slotEditSegmentPitchView(Segment *)));
-
-    //connect(m_trackEditor->getCompositionView(),
-    //        SIGNAL(editSegmentMatrix(Segment *)),
-    //        SLOT(slotEditSegmentMatrix(Segment *)));
-
-    //connect(m_trackEditor->getCompositionView(),
-    //        SIGNAL(editSegmentAudio(Segment *)),
-    //        SLOT(slotEditSegmentAudio(Segment *)));
-
-    //connect(m_trackEditor->getCompositionView(),
-    //        SIGNAL(audioSegmentAutoSplit(Segment *)),
-    //        SLOT(slotSegmentAutoSplit(Segment *)));
-
-    //connect(m_trackEditor->getCompositionView(),
-    //        SIGNAL(editSegmentEventList(Segment *)),
-    //        SLOT(slotEditSegmentEventList(Segment *)));
-
     connect(m_trackEditor->getCompositionView(),
             &CompositionView::editRepeat,
             this, &RosegardenMainViewWidget::slotEditRepeat);
@@ -302,7 +276,7 @@ void RosegardenMainViewWidget::slotEditSegment(Segment *segment)
                 slotEditSegmentMatrix(segment);
             }
 
-        } else if (client == GeneralConfigurationPage::EventView) {
+        } else if (client == GeneralConfigurationPage::EventListEditor) {
             slotEditSegmentEventList(segment);
         } else {
             slotEditSegmentNotation(segment);
@@ -405,21 +379,18 @@ RosegardenMainViewWidget::createNotationView(const std::vector<Segment *>& segme
             this, &RosegardenMainViewWidget::slotEditSegmentsPitchTracker);
     connect(notationView, &NotationView::editTriggerSegment,
             this, &RosegardenMainViewWidget::slotEditTriggerSegment);
-    // No such signal comes from NotationView
-    //connect(notationView, SIGNAL(staffLabelChanged(TrackId, QString)),
-    //        this, SLOT(slotChangeTrackLabel(TrackId, QString)));
 
     SequenceManager *sM = RosegardenDocument::currentDocument->getSequenceManager();
 
-    connect(sM, SIGNAL(insertableNoteOnReceived(int, int)),
-            notationView, SLOT(slotInsertableNoteOnReceived(int, int)));
-    connect(sM, SIGNAL(insertableNoteOffReceived(int, int)),
-            notationView, SLOT(slotInsertableNoteOffReceived(int, int)));
+    connect(sM, &SequenceManager::insertableNoteOnReceived,
+            notationView, &NotationView::slotInsertableNoteOnReceived);
+    connect(sM, &SequenceManager::insertableNoteOffReceived,
+            notationView, &NotationView::slotInsertableNoteOffReceived);
 
     connect(notationView, &NotationView::stepByStepTargetRequested,
             this, &RosegardenMainViewWidget::stepByStepTargetRequested);
-    connect(this, SIGNAL(stepByStepTargetRequested(QObject *)),
-            notationView, SLOT(slotStepByStepTargetRequested(QObject *)));
+    connect(this, &RosegardenMainViewWidget::stepByStepTargetRequested,
+            notationView, &NotationView::slotStepByStepTargetRequested);
 
     // Encourage the notation view window to open to the same
     // interval as the current segment view.  Since scrollToTime is
@@ -532,9 +503,6 @@ RosegardenMainViewWidget::createPitchTrackerView(const std::vector<Segment *>& s
 
     connect(pitchTrackerView, &EditViewBase::saveFile,
             RosegardenMainWindow::self(), &RosegardenMainWindow::slotFileSave);
-//  This probably is obsolete in Thorn.
-//    connect(pitchTrackerView, SIGNAL(jumpPlaybackTo(timeT)),
-//            RosegardenDocument::currentDocument, SLOT(slotSetPointerPosition(timeT)));
     connect(pitchTrackerView, &PitchTrackerView::openInNotation,
             this, &RosegardenMainViewWidget::slotEditSegmentsNotation);
     connect(pitchTrackerView, &PitchTrackerView::openInMatrix,
@@ -547,21 +515,18 @@ RosegardenMainViewWidget::createPitchTrackerView(const std::vector<Segment *>& s
             this, &RosegardenMainViewWidget::slotEditSegmentsPitchTracker);
     connect(pitchTrackerView, &NotationView::editTriggerSegment,
             this, &RosegardenMainViewWidget::slotEditTriggerSegment);
-    // No such signal comes from PitchTrackerView
-    //connect(pitchTrackerView, SIGNAL(staffLabelChanged(TrackId, QString)),
-    //        this, SLOT(slotChangeTrackLabel(TrackId, QString)));
 
     SequenceManager *sM = RosegardenDocument::currentDocument->getSequenceManager();
 
-    connect(sM, SIGNAL(insertableNoteOnReceived(int, int)),
-            pitchTrackerView, SLOT(slotInsertableNoteOnReceived(int, int)));
-    connect(sM, SIGNAL(insertableNoteOffReceived(int, int)),
-            pitchTrackerView, SLOT(slotInsertableNoteOffReceived(int, int)));
+    connect(sM, &SequenceManager::insertableNoteOnReceived,
+            pitchTrackerView, &PitchTrackerView::slotInsertableNoteOnReceived);
+    connect(sM, &SequenceManager::insertableNoteOffReceived,
+            pitchTrackerView, &PitchTrackerView::slotInsertableNoteOffReceived);
 
     connect(pitchTrackerView, &NotationView::stepByStepTargetRequested,
             this, &RosegardenMainViewWidget::stepByStepTargetRequested);
-    connect(this, SIGNAL(stepByStepTargetRequested(QObject *)),
-            pitchTrackerView, SLOT(slotStepByStepTargetRequested(QObject *)));
+    connect(this, &RosegardenMainViewWidget::stepByStepTargetRequested,
+            pitchTrackerView, &PitchTrackerView::slotStepByStepTargetRequested);
 
     // Encourage the notation view window to open to the same
     // interval as the current segment view.  Since scrollToTime is
@@ -730,15 +695,15 @@ RosegardenMainViewWidget::createMatrixView(const std::vector<Segment *>& segment
 
     SequenceManager *sM = RosegardenDocument::currentDocument->getSequenceManager();
 
-    connect(sM, SIGNAL(insertableNoteOnReceived(int, int)),
-            matrixView, SLOT(slotInsertableNoteOnReceived(int, int)));
-    connect(sM, SIGNAL(insertableNoteOffReceived(int, int)),
-            matrixView, SLOT(slotInsertableNoteOffReceived(int, int)));
+    connect(sM, &SequenceManager::insertableNoteOnReceived,
+            matrixView, &MatrixView::slotInsertableNoteOnReceived);
+    connect(sM, &SequenceManager::insertableNoteOffReceived,
+            matrixView, &MatrixView::slotInsertableNoteOffReceived);
 
     connect(matrixView, &MatrixView::stepByStepTargetRequested,
             this, &RosegardenMainViewWidget::stepByStepTargetRequested);
-    connect(this, SIGNAL(stepByStepTargetRequested(QObject *)),
-            matrixView, SLOT(slotStepByStepTargetRequested(QObject *)));
+    connect(this, &RosegardenMainViewWidget::stepByStepTargetRequested,
+            matrixView, &MatrixView::slotStepByStepTargetRequested);
 
     // Encourage the matrix view window to open to the same
     // interval as the current segment view.   Since scrollToTime is
@@ -801,7 +766,7 @@ void RosegardenMainViewWidget::slotEditSegmentsEventList(
              segmentsToEdit.begin();
          segmentIter != segmentsToEdit.end();
          ++segmentIter) {
-        EventView *view = createEventView(*segmentIter);
+        EventListEditor *view = createEventView(*segmentIter);
         if (view) {
             // ??? Why does it start out hidden?
             view->show();
@@ -1152,7 +1117,7 @@ RosegardenMainViewWidget::updateMeters()
         i->second = unknownState;
     }
 
-    for (Composition::trackcontainer::iterator i =
+    for (Composition::TrackMap::iterator i =
              RosegardenDocument::currentDocument->getComposition().getTracks().begin();
          i != RosegardenDocument::currentDocument->getComposition().getTracks().end(); ++i) {
 
@@ -1388,15 +1353,6 @@ RosegardenMainViewWidget::slotAddCommandToHistory(Command *command)
     CommandHistory::getInstance()->addCommand(command);
 }
 
-#if 0
-void
-RosegardenMainViewWidget::slotChangeTrackLabel(TrackId id,
-                                        QString label)
-{
-    m_trackEditor->getTrackButtons()->changeTrackName(id, label);
-}
-#endif
-
 void
 RosegardenMainViewWidget::slotAddAudioSegment(AudioFileId audioId,
                                        TrackId trackId,
@@ -1487,7 +1443,7 @@ RosegardenMainViewWidget::slotAddAudioSegmentDefaultPosition(AudioFileId audioFi
 
     TrackId bestSoFar = currentTrackId;
 
-    for (Composition::trackcontainer::const_iterator
+    for (Composition::TrackMap::const_iterator
             ti = comp.getTracks().begin();
             ti != comp.getTracks().end(); ++ti) {
 
@@ -1525,7 +1481,6 @@ RosegardenMainViewWidget::slotAddAudioSegmentDefaultPosition(AudioFileId audioFi
 }
 
 void
-// cppcheck-suppress passedByValue
 RosegardenMainViewWidget::slotDroppedNewAudio(QString audioDesc)
 {
     // If audio is not OK
@@ -1631,7 +1586,6 @@ RosegardenMainViewWidget::slotDroppedNewAudio(QString audioDesc)
 }
 
 void
-// cppcheck-suppress passedByValue
 RosegardenMainViewWidget::slotDroppedAudio(QString audioDesc)
 {
     QTextStream s(&audioDesc, QIODevice::ReadOnly);
@@ -1675,8 +1629,8 @@ RosegardenMainViewWidget::slotSetRecord(InstrumentId id, bool value)
     */
     /* #ifdef NOT_DEFINED
     Composition &comp = RosegardenDocument::currentDocument->getComposition();
-    Composition::trackcontainer &tracks = comp.getTracks();
-    Composition::trackiterator it;
+    Composition::TrackMap &tracks = comp.getTracks();
+    Composition::TrackMap::iterator it;
 
     for (it = tracks.begin(); it != tracks.end(); ++it) {
         if (comp.getSelectedTrack() == (*it).second->getId()) {
@@ -1858,15 +1812,15 @@ RosegardenMainViewWidget::initChordNameRuler()
     getTrackEditor()->getChordNameRuler()->setReady();
 }
 
-EventView *
+EventListEditor *
 RosegardenMainViewWidget::createEventView(Segment *segment)
 {
-    // EventView expects a vector because of EditViewBase.
+    // EventListEditor expects a vector because of EditViewBase.
     std::vector<Segment *> segments;
     segments.push_back(segment);
 
-    EventView *eventView = new EventView(RosegardenDocument::currentDocument,
-                                         segments);
+    EventListEditor *eventView = new EventListEditor(
+            RosegardenDocument::currentDocument, segments);
 
     connect(eventView, &EditViewBase::saveFile,
             RosegardenMainWindow::self(), &RosegardenMainWindow::slotFileSave);
@@ -1880,7 +1834,7 @@ RosegardenMainViewWidget::createEventView(Segment *segment)
             this, &RosegardenMainViewWidget::slotEditSegmentsEventList);
     connect(eventView, &EditViewBase::openInPitchTracker,
             this, &RosegardenMainViewWidget::slotEditSegmentsPitchTracker);
-    connect(eventView, &EventView::editTriggerSegment,
+    connect(eventView, &EventListEditor::editTriggerSegment,
             this, &RosegardenMainViewWidget::slotEditTriggerSegment);
 
     return eventView;
