@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -40,6 +40,7 @@ class Command;
 namespace Rosegarden
 {
 
+
 class TrackParameterBox;
 class TrackEditor;
 class SimpleRulerScale;
@@ -54,7 +55,7 @@ class PitchTrackerView;
 class MatrixView;
 class MappedEvent;
 class InstrumentParameterBox;
-class EventView;
+class EventListEditor;
 class Composition;
 class LevelInfo;
 
@@ -198,11 +199,6 @@ public slots:
      */
     void slotAddCommandToHistory(Command *command);
 
-    /**
-     * Change the Track Label
-     */
-//    void slotChangeTrackLabel(TrackId id, QString label);
-
     /// Set the record state for an instrument.
     // unused void slotSetRecord(InstrumentId, bool);
 
@@ -274,7 +270,7 @@ private:
 
     void createNotationView(const std::vector<Segment *>&);
     void createMatrixView(const std::vector<Segment *>&, bool drumMode);
-    EventView *createEventView(Segment *);
+    EventListEditor *createEventView(Segment *);
     PitchTrackerView *createPitchTrackerView(const std::vector<Segment *>&);
 
     static bool hasNonAudioSegment(const SegmentSelection &segments);
