@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -19,7 +19,6 @@
 #define RG_ROSEGARDENMAINWINDOW_H
 
 #include "base/MidiProgram.h"
-#include "gui/dialogs/TempoDialog.h"
 #include "gui/widgets/ZoomSlider.h"
 #include "gui/general/RecentFiles.h"
 #include "base/Event.h"
@@ -39,6 +38,7 @@
 #include <QToolBar>
 #include <QPointer>
 #include <QSharedPointer>
+#include <QTime>
 
 #include <map>
 #include <set>
@@ -67,6 +67,7 @@ class TrackParameterBox;
 class TempoAndTimeSignatureEditor;
 class SynthPluginManagerDialog;
 class StartupTester;
+class StartupLogo;
 class SequenceManager;
 class SegmentParameterBox;
 class RosegardenParameterArea;
@@ -131,14 +132,7 @@ class ROSEGARDENPRIVATE_EXPORT RosegardenMainWindow :
 
 public:
 
-    /**
-     * constructor of RosegardenMainWindow, calls all init functions to
-     * create the application.
-     * \arg useSequencer : if true, the sequencer is launched
-     * @see initMenuBar initToolBar
-     */
-    RosegardenMainWindow(bool enableSound = true,
-                         QObject *startupStatusMessageReceiver = nullptr);
+    RosegardenMainWindow(bool enableSound, StartupLogo *startupLogo);
 
     ~RosegardenMainWindow() override;
 
@@ -179,18 +173,18 @@ public:
     /// merge a file, explicitly specifying its type, allow multiple files
     void mergeFile(QStringList filePathList, ImportType type);
 
-    void openURL(const QUrl &url, bool replace);
+    bool openURL(const QUrl &url, bool replace);
 
-    void exportMIDIFile(QString file);
+    bool exportMIDIFile(QString file);
 
     /// export a Csound scorefile
-    void exportCsoundFile(QString file);
+    bool exportCsoundFile(QString file);
 
-    void exportMupFile(QString file);
+    bool exportMupFile(QString file);
 
-    bool exportLilyPondFile(QString file, bool forPreview = false);
+    bool exportLilyPondFile(const QString &file, bool forPreview = false);
 
-    void exportMusicXmlFile(QString file);
+    bool exportMusicXmlFile(QString file);
 
     SequenceManager *getSequenceManager() { return m_seqManager; }
 
@@ -296,8 +290,11 @@ protected:
      *   - false: This is a temporary document and is not allowed to make
      *            changes to ALSA and any audio or MIDI connections.
      *   - See RosegardenDocument::m_soundEnabled.
+     *
+     * If the path is not empty that file will be loaded but the document
+     * will still be considered "new" - no filename will be set
      */
-    RosegardenDocument *newDocument(bool permanent);
+    RosegardenDocument *newDocument(bool permanent, const QString& path = "");
 
     /**** File handling code that we don't want the outside world to use ****/
     /**/
@@ -310,14 +307,14 @@ protected:
             QString filePath,
             ImportType importType,
             bool permanent,
-            bool lock,
+            bool revert,
             bool clearHistory);
 
     /**
      * Create a document from RG file
      */
     RosegardenDocument *createDocumentFromRGFile(
-            const QString &filePath, bool permanent, bool lock,
+            const QString &filePath, bool permanent, bool revert,
             bool clearHistory);
 
     /**
@@ -557,8 +554,8 @@ public slots:
      * be saved read-only, to make it harder to overwrite by accident in the
      * future
      */
-    bool slotFileSaveAs(bool asTemplate = false);
-    void slotFileSaveAsTemplate() { slotFileSaveAs(true); }
+    void slotFileSaveAs() { fileSaveAs(false); }
+    void slotFileSaveAsTemplate() { fileSaveAs(true); }
 
     /**
      * asks for saving if the file is modified, then closes the actual
@@ -1409,7 +1406,7 @@ public slots:
     void slotMarkerEditorClosed();
 
     /**
-     * when TempoView is being closed
+     * when TempoAndTimeSignatureEditor is being closed
      */
     void slotTempoViewClosed();
 
@@ -1516,9 +1513,6 @@ public slots:
     void slotCommandRedone();
     void slotUpdatePosition();
 
-protected slots:
-    void setupRecentFilesMenu();
-
 private:
     /** Use QTemporaryFile to obtain a tmp filename that is guaranteed to be
      * unique
@@ -1553,53 +1547,52 @@ private:
      */
     void initStaticObjects();
 
-    //--------------- Data members ---------------------------------
+    bool fileSaveAs(bool asTemplate);
 
-    bool m_actionsSetup;
+    bool m_actionsSetup{false};
 
     // Action States
-    bool m_notPlaying;
-    bool m_haveSelection;
-    bool m_haveRange;
+    bool m_notPlaying{true};
+    bool m_haveSelection{false};
+    bool m_haveRange{false};
     void updateActions();
 
-    RosegardenMainViewWidget *m_view;
+    RosegardenMainViewWidget *m_view{nullptr};
 
     /**
      *    Menus
      */
     RecentFiles m_recentFiles;
 
-    SequencerThread *m_sequencerThread;
-    bool m_sequencerCheckedIn;
+    SequencerThread *m_sequencerThread{nullptr};
+    bool m_sequencerCheckedIn{false};
 
     /// CPU meter in the main window status bar.
     /**
      * This is NOT a general-purpose progress indicator.  You want to use
      * QProgressDialog for that.
      */
-    ProgressBar *m_cpuBar;
+    ProgressBar *m_cpuBar{nullptr};
 
-    ZoomSlider<double> *m_zoomSlider;
-    QLabel             *m_zoomLabel;
+    ZoomSlider<double> *m_zoomSlider{nullptr};
+    QLabel *m_zoomLabel{nullptr};
 
 
-//    QLabel *m_statusBarLabel1;
     // SequenceManager
     //
-    SequenceManager *m_seqManager;
+    SequenceManager *m_seqManager{nullptr};
 
     // Transport dialog pointer
     //
-    TransportDialog *m_transport;
+    TransportDialog *m_transport{nullptr};
 
     // Dialogs which depend on the document
 
     // Audio file manager
     //
-    AudioManagerDialog *m_audioManagerDialog;
+    AudioManagerDialog *m_audioManagerDialog{nullptr};
 
-    bool m_originatingJump;
+    bool m_originatingJump{false};
 
     bool m_useSequencer;
 
@@ -1609,24 +1602,24 @@ private:
 
     Clipboard *m_clipboard;
 
-    SegmentParameterBox           *m_segmentParameterBox;
-    InstrumentParameterBox        *m_instrumentParameterBox;
-    TrackParameterBox             *m_trackParameterBox;
+    SegmentParameterBox *m_segmentParameterBox{nullptr};
+    InstrumentParameterBox *m_instrumentParameterBox{nullptr};
+    TrackParameterBox *m_trackParameterBox{nullptr};
 
-    PlayListDialog        *m_playList;
-    SynthPluginManagerDialog *m_synthManager;
+    PlayListDialog *m_playList{nullptr};
+    SynthPluginManagerDialog *m_synthManager{nullptr};
     QPointer<AudioMixerWindow2> m_audioMixerWindow2;
-    MidiMixerWindow       *m_midiMixer;
-    BankEditorDialog      *m_bankEditor;
-    MarkerEditor          *m_markerEditor;
-    TempoAndTimeSignatureEditor *m_tempoAndTimeSignatureEditor;
-    TriggerSegmentManager *m_triggerSegmentManager;
-    ConfigureDialog       *m_configDlg;
-    DocumentConfigureDialog *m_docConfigDlg;
+    MidiMixerWindow *m_midiMixer{nullptr};
+    BankEditorDialog *m_bankEditor{nullptr};
+    MarkerEditor *m_markerEditor{nullptr};
+    TempoAndTimeSignatureEditor *m_tempoAndTimeSignatureEditor{nullptr};
+    TriggerSegmentManager *m_triggerSegmentManager{nullptr};
+    ConfigureDialog *m_configDlg{nullptr};
+    DocumentConfigureDialog *m_docConfigDlg{nullptr};
     std::set<ControlEditorDialog *> m_controlEditors;
     /// List of plugin dialogs to make sure we don't launch more than one.
     std::map<int, AudioPluginDialog*> m_pluginDialogs;
-    AudioPluginGUIManager *m_pluginGUIManager;
+    AudioPluginGUIManager *m_pluginGUIManager{nullptr};
 
     static RosegardenMainWindow *m_myself;
 
@@ -1635,24 +1628,22 @@ private:
     QTimer *m_updateUITimer;
     QTimer *m_inputTimer;
 
-    EditTempoController *m_editTempoController;
+    StartupTester *m_startupTester{nullptr};
 
-    StartupTester *m_startupTester;
+    bool m_firstRun{false};
+    bool m_haveAudioImporter{false};
 
-    bool m_firstRun;
-    bool m_haveAudioImporter;
-
-    RosegardenParameterArea *m_parameterArea;
+    RosegardenParameterArea *m_parameterArea{nullptr};
 
 #ifdef HAVE_LIRC
-    LircClient *m_lircClient;
-    LircCommander *m_lircCommander;
+    LircClient *m_lircClient{nullptr};
+    LircCommander *m_lircCommander{nullptr};
 #endif
-    TranzportClient *m_tranzport;
+    TranzportClient *m_tranzport{nullptr};
 
     QPointer<DeviceManagerDialog> m_deviceManager;
 
-    WarningWidget *m_warningWidget;
+    WarningWidget *m_warningWidget{nullptr};
 
     // Ladish lv1 support
     static int sigpipe[2];
@@ -1676,9 +1667,15 @@ private:
     // shortcuts for most recent file
     QList<QKeySequence> m_mostRecentShortcuts;
 
+    unsigned m_autoSaveInterval{0};
+    QTime m_lastAutoSaveTime;
+
     void doStop(bool autoStop);
 
 private slots:
+
+    void setupRecentFilesMenu();
+
     void signalAction(int);
 
     // New routines to handle inputs and UI updates
@@ -1695,6 +1692,7 @@ private slots:
     void slotMuteAllTracks();
     void slotUnmuteAllTracks();
 
+    void slotCommandExecuted();
 };
 
 
