@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -27,7 +27,7 @@
 #include "misc/Preferences.h"
 #include "document/RosegardenDocument.h"
 #include "sequencer/RosegardenSequencer.h"
-#include "gui/application/RosegardenMainWindow.h"
+#include "sound/ExternalController.h"
 #include "gui/seqmanager/SequenceManager.h"
 #include "base/Studio.h"
 #include "gui/studio/StudioControl.h"
@@ -75,8 +75,7 @@ MIDIConfigurationPage::MIDIConfigurationPage(QWidget *parent):
     m_baseOctaveNumber = new QSpinBox;
     m_baseOctaveNumber->setMinimum(-10);
     m_baseOctaveNumber->setMaximum(10);
-    m_baseOctaveNumber->setValue(
-            settings.value("midipitchoctave", -2).toInt());
+    m_baseOctaveNumber->setValue(Preferences::getMIDIPitchOctave());
     connect(m_baseOctaveNumber,
                 static_cast<void(QSpinBox::*)(int)>(&QSpinBox::valueChanged),
             this, &MIDIConfigurationPage::slotModified);
@@ -489,7 +488,7 @@ MIDIConfigurationPage::apply()
     QSettings settings;
     settings.beginGroup(GeneralOptionsConfigGroup);
 
-    settings.setValue("midipitchoctave", m_baseOctaveNumber->value());
+    Preferences::setMIDIPitchOctave(m_baseOctaveNumber->value());
     settings.setValue("alwaysusedefaultstudio",
                       m_useDefaultStudio->isChecked());
 
