@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -51,98 +51,97 @@ namespace Rosegarden
 
 TempoDialog::TempoDialog(QWidget *parent, RosegardenDocument *doc,
                          bool timeEditable):
-        QDialog(parent),
-        m_doc(doc),
-        m_tempoTime(0)
+    QDialog(parent),
+    m_doc(doc)
 {
     setModal(true);
     setWindowTitle(tr("Insert Tempo Change"));
-    setObjectName("MinorDialog");
 
-    QWidget* vbox = dynamic_cast<QWidget*>(this);
     QVBoxLayout *vboxLayout = new QVBoxLayout;
-    vbox->setLayout(vboxLayout);
+    setLayout(vboxLayout);
 
-    // group box for tempo
-    QGroupBox *frame = new QGroupBox(tr("Tempo"), vbox);
-    frame->setContentsMargins(5, 5, 5, 5);
-    QGridLayout *layout = new QGridLayout;
-    layout->setSpacing(5);
-    vboxLayout->addWidget(frame);
+    // Tempo group box
+    QGroupBox *tempoGroupBox = new QGroupBox(tr("Tempo"), this);
+    tempoGroupBox->setContentsMargins(5, 5, 5, 5);
+    QGridLayout *tempoLayout = new QGridLayout;
+    tempoLayout->setSpacing(5);
+    tempoGroupBox->setLayout(tempoLayout);
+    vboxLayout->addWidget(tempoGroupBox);
 
-    // Set tempo
-    layout->addWidget(new QLabel(tr("New tempo:"), frame), 0, 1);
-    m_tempoValueSpinBox = new QDoubleSpinBox(frame);
+    // New tempo
+    tempoLayout->addWidget(new QLabel(tr("New tempo:"), tempoGroupBox), 0, 1);
+    m_tempoValueSpinBox = new QDoubleSpinBox(tempoGroupBox);
     m_tempoValueSpinBox->setDecimals(3);
     m_tempoValueSpinBox->setMaximum(1000);
     m_tempoValueSpinBox->setMinimum(1);
     m_tempoValueSpinBox->setSingleStep(1);
     m_tempoValueSpinBox->setValue(120); // will set properly below
-    layout->addWidget(m_tempoValueSpinBox, 0, 2);
-
     connect(m_tempoValueSpinBox, SIGNAL(valueChanged(double)),
             SLOT(slotTempoChanged(double)));
+    tempoLayout->addWidget(m_tempoValueSpinBox, 0, 2);
 
-    m_tempoTap= new QPushButton(tr("Tap"), frame);
-    layout->addWidget(m_tempoTap, 0, 3);
+    // Tap
+    m_tempoTap = new QPushButton(tr("Tap"), tempoGroupBox);
     connect(m_tempoTap, &QAbstractButton::clicked, this, &TempoDialog::slotTapClicked);
+    tempoLayout->addWidget(m_tempoTap, 0, 3);
 
+    // bpm
+    m_tempoBeatLabel = new QLabel(tempoGroupBox);
+    tempoLayout->addWidget(m_tempoBeatLabel, 0, 4);
 
-    m_tempoConstant = new QRadioButton(tr("Tempo is fixed until the following tempo change"), frame);
-    m_tempoRampToNext = new QRadioButton(tr("Tempo ramps to the following tempo"), frame);
-    m_tempoRampToTarget = new QRadioButton(tr("Tempo ramps to:"), frame);
+    m_tempoBeat = new QLabel(tempoGroupBox);
+    tempoLayout->addWidget(m_tempoBeat, 0, 5);
 
-    //    m_tempoTargetCheckBox = new QCheckBox(tr("Ramping to:"), frame);
-    m_tempoTargetSpinBox = new QDoubleSpinBox(frame);
+    m_tempoBeatsPerMinute = new QLabel(tempoGroupBox);
+    tempoLayout->addWidget(m_tempoBeatsPerMinute, 0, 6);
+
+    // Tempo is fixed...
+    m_tempoConstant = new QRadioButton(
+            tr("Tempo is fixed until the following tempo change"), tempoGroupBox);
+    connect(m_tempoConstant, &QAbstractButton::clicked,
+            this, &TempoDialog::slotTempoConstantClicked);
+    tempoLayout->addWidget(m_tempoConstant, 1, 1, 1, 2);
+
+    // Tempo ramps to the following tempo
+    m_tempoRampToNext = new QRadioButton(
+            tr("Tempo ramps to the following tempo"), tempoGroupBox);
+    connect(m_tempoRampToNext, &QAbstractButton::clicked,
+            this, &TempoDialog::slotTempoRampToNextClicked);
+    tempoLayout->addWidget(m_tempoRampToNext, 2, 1, 1, 2);
+
+    // Tempo ramps to:
+    // ??? This one is a bit confusing.  It ramps to the specified tempo, but
+    //     the ramp stops at the next tempo no matter what that tempo might be.
+    //     A tooltip might be helpful here.
+    m_tempoRampToTarget = new QRadioButton(tr("Tempo ramps to:"), tempoGroupBox);
+    connect(m_tempoRampToTarget, &QAbstractButton::clicked,
+            this, &TempoDialog::slotTempoRampToTargetClicked);
+    tempoLayout->addWidget(m_tempoRampToTarget, 3, 1);
+    m_tempoTargetSpinBox = new QDoubleSpinBox(tempoGroupBox);
     m_tempoTargetSpinBox->setDecimals(3);
     m_tempoTargetSpinBox->setMaximum(1000);
     m_tempoTargetSpinBox->setMinimum(1);
     m_tempoTargetSpinBox->setSingleStep(1);
     m_tempoTargetSpinBox->setValue(120);
-
-    //    layout->addWidget(m_tempoTargetCheckBox, 1, 0, 0+1, 1- 1, AlignRight);
-    //    layout->addWidget(m_tempoTargetSpinBox, 1, 2);
-
-    layout->addWidget(m_tempoConstant, 1, 1, 1, 2);
-    layout->addWidget(m_tempoRampToNext, 2, 1, 1, 2);
-    layout->addWidget(m_tempoRampToTarget, 3, 1);
-    layout->addWidget(m_tempoTargetSpinBox, 3, 2);
-
-    //    connect(m_tempoTargetCheckBox, SIGNAL(clicked()),
-    //            SLOT(slotTargetCheckBoxClicked()));
-    connect(m_tempoConstant, &QAbstractButton::clicked,
-            this, &TempoDialog::slotTempoConstantClicked);
-    connect(m_tempoRampToNext, &QAbstractButton::clicked,
-            this, &TempoDialog::slotTempoRampToNextClicked);
-    connect(m_tempoRampToTarget, &QAbstractButton::clicked,
-            this, &TempoDialog::slotTempoRampToTargetClicked);
     connect(m_tempoTargetSpinBox, SIGNAL(valueChanged(double)),
             SLOT(slotTargetChanged(double)));
-
-    m_tempoBeatLabel = new QLabel(frame);
-    layout->addWidget(m_tempoBeatLabel, 0, 4);
-
-    m_tempoBeat = new QLabel(frame);
-    layout->addWidget(m_tempoBeat, 0, 5);
-
-    m_tempoBeatsPerMinute = new QLabel(frame);
-    layout->addWidget(m_tempoBeatsPerMinute, 0, 6);
-
-    frame->setLayout(layout);
-
-    m_timeEditor = nullptr;
+    tempoLayout->addWidget(m_tempoTargetSpinBox, 3, 2);
 
     if (timeEditable) {
 
-        m_timeEditor = new TimeWidget
-            (tr("Time of tempo change"),
-             vbox, &m_doc->getComposition(), 0, true);
+        m_timeEditor = new TimeWidget(
+                tr("Time of tempo change"),  // title
+                this,  // parent
+                &m_doc->getComposition(),  // composition
+                0,  // initialTime
+                true);  // editable
+
         vboxLayout->addWidget(m_timeEditor);
 
     } else {
 
         // group box for scope (area)
-        QGroupBox *scopeGroup = new QGroupBox(tr("Scope"), vbox);
+        QGroupBox *scopeGroup = new QGroupBox(tr("Scope"), this);
         vboxLayout->addWidget(scopeGroup);
 
         QVBoxLayout * scopeBoxLayout = new QVBoxLayout(scopeGroup);
@@ -179,19 +178,23 @@ TempoDialog::TempoDialog(QWidget *parent, RosegardenDocument *doc,
         changeWhereBox->setLayout(changeWhereBoxLayout);
         changeWhereBoxLayout->setStretchFactor(changeWhereVBox, 20);
 
-        m_tempoChangeHere = new QRadioButton(tr("Apply this tempo from here onwards"), changeWhereVBox);
+        m_tempoChangeHere = new QRadioButton(
+                tr("Apply this tempo from here onwards"), changeWhereVBox);
         changeWhereVBoxLayout->addWidget(m_tempoChangeHere);
 
-        m_tempoChangeBefore = new QRadioButton(tr("Replace the last tempo change"), changeWhereVBox);
+        m_tempoChangeBefore = new QRadioButton(
+                tr("Replace the last tempo change"), changeWhereVBox);
         changeWhereVBoxLayout->addWidget(m_tempoChangeBefore);
         m_tempoChangeBeforeAt = new QLabel(changeWhereVBox);
         changeWhereVBoxLayout->addWidget(m_tempoChangeBeforeAt);
         m_tempoChangeBeforeAt->hide();
 
-        m_tempoChangeStartOfBar = new QRadioButton(tr("Apply this tempo from the start of this bar"), changeWhereVBox);
+        m_tempoChangeStartOfBar = new QRadioButton(
+                tr("Apply this tempo from the start of this bar"), changeWhereVBox);
         changeWhereVBoxLayout->addWidget(m_tempoChangeStartOfBar);
 
-        m_tempoChangeGlobal = new QRadioButton(tr("Apply this tempo to the whole composition"), changeWhereVBox);
+        m_tempoChangeGlobal = new QRadioButton(
+                tr("Apply this tempo to the whole composition"), changeWhereVBox);
         changeWhereVBoxLayout->addWidget(m_tempoChangeGlobal);
 
         QWidget *optionHBox = new QWidget(changeWhereVBox);
@@ -200,7 +203,8 @@ TempoDialog::TempoDialog(QWidget *parent, RosegardenDocument *doc,
         QHBoxLayout *optionHBoxLayout = new QHBoxLayout;
         QLabel *child_6 = new QLabel("         ", optionHBox);
         optionHBoxLayout->addWidget(child_6);
-        m_defaultBox = new QCheckBox(tr("Also make this the default tempo"), optionHBox);
+        m_defaultBox = new QCheckBox(
+                tr("Also make this the default tempo"), optionHBox);
         optionHBoxLayout->addWidget(m_defaultBox);
         spare = new QLabel(optionHBox);
         optionHBoxLayout->addWidget(spare);
@@ -222,12 +226,15 @@ TempoDialog::TempoDialog(QWidget *parent, RosegardenDocument *doc,
         m_defaultBox->setEnabled(false);
     }
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(
+            QDialogButtonBox::Ok | QDialogButtonBox::Cancel |
+            QDialogButtonBox::Help);
     vboxLayout->addWidget(buttonBox);
 
     connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
     connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
-    connect(buttonBox, &QDialogButtonBox::helpRequested, this, &TempoDialog::slotHelpRequested);
+    connect(buttonBox, &QDialogButtonBox::helpRequested,
+            this, &TempoDialog::slotHelpRequested);
 
     populateTempo();
 }
@@ -432,23 +439,26 @@ TempoDialog::slotActionChanged()
 void
 TempoDialog::accept()
 {
-    tempoT tempo = Composition::getTempoForQpm(m_tempoValueSpinBox->value());
-    RG_DEBUG << "Tempo is " << tempo;
+    m_tempo = Composition::getTempoForQpm(m_tempoValueSpinBox->value());
+    RG_DEBUG << "Tempo is " << m_tempo;
 
-    tempoT target = -1;
+    m_targetTempo = -1;
     if (m_tempoRampToNext->isChecked()) {
-        target = 0;
+        m_targetTempo = 0;
     } else if (m_tempoRampToTarget->isChecked()) {
-        target = Composition::getTempoForQpm(m_tempoTargetSpinBox->value());
+        m_targetTempo =
+                Composition::getTempoForQpm(m_tempoTargetSpinBox->value());
     }
 
-    RG_DEBUG << "Target is " << target;
+    RG_DEBUG << "Target is " << m_targetTempo;
 
     if (m_timeEditor) {
 
-        emit changeTempo(m_timeEditor->getTime(),
-                         tempo,
-                         target,
+        m_tempoTime = m_timeEditor->getTime();
+
+        emit changeTempo(m_tempoTime,
+                         m_tempo,
+                         m_targetTempo,
                          AddTempo);
 
     } else {
@@ -467,8 +477,8 @@ TempoDialog::accept()
         }
 
         emit changeTempo(m_tempoTime,
-                         tempo,
-                         target,
+                         m_tempo,
+                         m_targetTempo,
                          action);
     }
 
