@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -25,7 +25,6 @@
 #include "MatrixWidget.h"
 #include "MatrixElement.h"
 
-#include "gui/application/RosegardenMainWindow.h"
 #include "document/RosegardenDocument.h"
 #include "document/CommandHistory.h"
 #include "misc/ConfigGroups.h"
@@ -1085,7 +1084,7 @@ MatrixScene::constrainToSegmentArea(QPointF &scenePos)
 */
 
 void
-MatrixScene::playNote(Segment &segment, int pitch, int velocity)
+MatrixScene::playNote(const Segment &segment, int pitch, int velocity)
 {
 //    std::cout << "Scene is playing a note of pitch: " << pitch
 //              << " + " <<  segment.getTranspose();
@@ -1126,6 +1125,29 @@ MatrixScene::updateAll()
     updateCurrentSegment();
 }
 
+void
+MatrixScene::setExtraPreviewEvents(const EventWithSegmentMap& events)
+{
+    RG_DEBUG << "setExtraPreviewEvents" << events.size();
+    for (auto pair : events) {
+        const Event* e = pair.first;
+        const Segment* segment = pair.second;
+        if (m_additionalPreviewEvents.find(e) !=
+            m_additionalPreviewEvents.end()) continue; // already previewed
+
+        long pitch;
+        if (e->get<Int>(BaseProperties::PITCH, pitch)) {
+            long velocity = -1;
+            (void)(e->get<Int>(BaseProperties::VELOCITY, velocity));
+            if (!(e->has(BaseProperties::TIED_BACKWARD) &&
+                  e->get<Bool>(BaseProperties::TIED_BACKWARD))) {
+                playNote(*segment, pitch, velocity);
+            }
+        }
+    }
+    m_additionalPreviewEvents = events;
+}
+
 int
 MatrixScene::findSegmentIndex(const Segment *segment) const
 {
