@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -125,7 +125,7 @@ public:
 
     // unused bool constrainToSegmentArea(QPointF &scenePos);
 
-    void playNote(Segment &segment, int pitch, int velocity = -1);
+    void playNote(const Segment &segment, int pitch, int velocity = -1);
 
     // SegmentObserver method forwarded from MatrixViewSegment
     void segmentEndMarkerTimeChanged(const Segment *s, bool shorten);
@@ -138,6 +138,10 @@ public:
     /// update all ViewSegments
     void updateAll();
 
+    // extra preview events
+    typedef std::map<const Event*, const Segment*> EventWithSegmentMap;
+    void setExtraPreviewEvents(const EventWithSegmentMap& events);
+
 signals:
     void mousePressed(const MatrixMouseEvent *e);
     void mouseMoved(const MatrixMouseEvent *e);
@@ -207,6 +211,8 @@ private:
     std::vector<QGraphicsLineItem *> m_verticals;
     std::vector<QGraphicsRectItem *> m_highlights;
 
+    EventWithSegmentMap m_additionalPreviewEvents;
+
     void setupMouseEvent(QGraphicsSceneMouseEvent *, MatrixMouseEvent &) const;
     void recreateLines();
     void recreateTriadHighlights();
