@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -54,6 +54,9 @@ public:
     virtual void handleMouseDoubleClick(const MatrixMouseEvent *);
     virtual FollowMode handleMouseMove(const MatrixMouseEvent *);
 
+    virtual void keyPressEvent(QKeyEvent*) { }
+    virtual void keyReleaseEvent(QKeyEvent*) { }
+
 public slots:
     /**
      * Respond to an event being deleted -- it may be one that the
