@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -98,13 +98,18 @@ signals:
     void panic();
 
     void stepByStepTargetRequested(QObject *);
-    void changeTempo(timeT,  // tempo change time
-                     tempoT,  // tempo value
-                     tempoT,  // target value
-                     TempoDialog::TempoDialogAction); // tempo action
 
     void noteInsertedFromKeyboard(Segment * segment, int pitch);
 
+public slots:
+    /// Note-on received asynchronously -- consider step-by-step editing
+    void slotInsertableNoteOnReceived(int pitch, int velocity);
+
+    /// Note-off received asynchronously -- consider step-by-step editing
+    void slotInsertableNoteOffReceived(int pitch, int velocity);
+
+    void slotStepByStepTargetRequested(QObject *);
+
 protected slots:
     /// Remove a segment from our list when it is deleted from the composition
     void slotSegmentDeleted(Segment *);
@@ -224,7 +229,7 @@ protected slots:
     void slotJogRight();
 
     void slotStepBackward();
-    void slotStepForward(bool force = false);
+    void slotStepForward()  { stepForward(false); }
 
     void slotExtendSelectionBackward();
     void slotExtendSelectionForward();
@@ -236,20 +241,14 @@ protected slots:
     /// keyboard insert
     void slotInsertNoteFromAction();
 
-    /// Note-on received asynchronously -- consider step-by-step editing
-    void slotInsertableNoteOnReceived(int pitch, int velocity);
-
-    /// Note-off received asynchronously -- consider step-by-step editing
-    void slotInsertableNoteOffReceived(int pitch, int velocity);
-
     /// Note-on or note-off received asynchronously -- as above
     void slotInsertableNoteEventReceived(int pitch, int velocity, bool noteOn);
 
     void slotPitchBendSequence();
     void slotControllerSequence();
 
+    void slotConstrainedMove();
     void slotToggleStepByStep();
-    void slotStepByStepTargetRequested(QObject *);
 
     /** Update the window title.  If m is true (normally comes from a signal)
      * display a * at the extreme left of the title to indicate modified status
@@ -310,6 +309,8 @@ private:
 
     void readOptions();
 
+    void stepForward(bool force);
+
 };
 
 }
