@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -35,8 +35,6 @@
 
 #include "document/RosegardenDocument.h"
 
-#include "gui/application/RosegardenMainWindow.h"
-
 #include "gui/widgets/Panner.h"
 #include "gui/widgets/Panned.h"
 #include "gui/widgets/Thumbwheel.h"
@@ -1117,6 +1115,14 @@ MatrixWidget::addControlRuler(QAction *action)
     }
 }
 
+void
+MatrixWidget::getZoomFactors(double& horizontalZoomFactor,
+                             double& verticalZoomFactor) const
+{
+    horizontalZoomFactor = m_hZoomFactor;
+    verticalZoomFactor = m_vZoomFactor;
+}
+
 void
 MatrixWidget::slotHScrollBarRangeChanged(int min, int max)
 {
@@ -1733,4 +1739,16 @@ MatrixWidget::slotZoomOut()
     slotHorizontalThumbwheelMoved(v);
 }
 
+void MatrixWidget::keyPressEvent(QKeyEvent *e)
+{
+    if (m_currentTool) m_currentTool->keyPressEvent(e);
+    QWidget::keyPressEvent(e);
+}
+
+void MatrixWidget::keyReleaseEvent(QKeyEvent *e)
+{
+    if (m_currentTool) m_currentTool->keyReleaseEvent(e);
+    QWidget::keyReleaseEvent(e);
+}
+
 }
