@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -186,6 +186,9 @@ public:
     /// View > Rulers > Add Control Ruler
     void addControlRuler(QAction *);
 
+    void getZoomFactors(double& horizontalZoomFactor,
+                        double& verticalZoomFactor) const;
+
 signals:
     void toolChanged(QString);
 
@@ -349,6 +352,9 @@ private:
     void zoomInFromPanner();
     void zoomOutFromPanner();
 
+    void keyPressEvent(QKeyEvent *e) override;
+    void keyReleaseEvent(QKeyEvent *e) override;
+
     QWidget *m_changerWidget;
     Thumbwheel *m_segmentChanger;
     int m_lastSegmentChangerValue;
