@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -34,7 +34,7 @@ namespace Rosegarden
 
 static const int NotationElementData = 1;
 
-NotationElement::NotationElement(Event *event) :
+NotationElement::NotationElement(Event *event, Segment *segment) :
     ViewElement(event),
     m_airX(0),
     m_airWidth(0),
@@ -42,7 +42,8 @@ NotationElement::NotationElement(Event *event) :
     m_isColliding(false),
     m_item(nullptr),
     m_extraItems(nullptr),
-    m_highlight(true)
+    m_highlight(true),
+    m_segment(segment)
 {
     //RG_DEBUG << "ctor: " << this << " wrapping " << event;
 }
