@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -24,6 +24,7 @@
 #include "base/Event.h"
 #include "base/NotationRules.h"
 #include "base/NotationTypes.h"
+#include "base/Pitch.h"
 #include "base/Quantizer.h"
 #include "gui/editors/notation/NotationChord.h"
 #include "gui/editors/notation/NotationElement.h"
@@ -181,6 +182,7 @@ NotationGroup::sample(const NELIterator &i, bool goingForwards)
 void
 NotationGroup::initialiseFinish() {}
 
+#if 0
 bool
 NotationGroup::contains(const NELIterator &i) const
 {
@@ -195,6 +197,7 @@ NotationGroup::contains(const NELIterator &i) const
         ++j;
     }
 }
+#endif
 
 int
 NotationGroup::height(const NELIterator &i) const
@@ -280,12 +283,12 @@ NotationGroup::applyStemProperties()
 
     /*!!!
         if ((*initialNote)->event()->has(STEM_UP) &&
-        (*initialNote)->event()->isPersistent<Bool>(STEM_UP)) {
+        (*initialNote)->event()->isPersistent(STEM_UP)) {
         aboveNotes = (*initialNote)->event()->get<Bool>(STEM_UP);
         }
 
         if ((*initialNote)->event()->has(NotationProperties::BEAM_ABOVE) &&
-        (*initialNote)->event()->isPersistent<Bool>(NotationProperties::BEAM_ABOVE)) {
+        (*initialNote)->event()->isPersistent(NotationProperties::BEAM_ABOVE)) {
         aboveNotes = (*initialNote)->event()->get<Bool>
             (NotationProperties::BEAM_ABOVE);
         }
