@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -95,7 +95,6 @@ NotationScene::NotationScene() :
 
 //    qRegisterMetaType<NotationMouseEvent>("Rosegarden::NotationMouseEvent");
 
-    m_segmentsDeleted.clear();
     setNotePixmapFactories();
 }
 
@@ -282,9 +281,9 @@ NotationScene::setCurrentStaff(NotationStaff *staff)
         RG_DEBUG << "highlight iter" << iStaff << iSegment << onSameTrack;
         bool highlight = true;
         if (iSegment != currentSegment && onSameTrack &&
-            m_highlightMode == "highlight_current_on_track") highlight = false;
+            m_highlightMode == "highlight_within_track") highlight = false;
         if (iStaff != currentStaff &&
-            m_highlightMode == "highlight_current") highlight = false;
+            m_highlightMode == "highlight") highlight = false;
         // do not affect repeats
         if (iSegment->isTmp()) highlight = true;
 
@@ -2182,7 +2181,7 @@ NotationScene::clearPreviewNote()
 }
 
 void
-NotationScene::playNote(Segment &segment, int pitch, int velocity)
+NotationScene::playNote(const Segment &segment, int pitch, int velocity)
 {
     if (!m_document) return;
 
@@ -2339,6 +2338,28 @@ NotationScene::dumpBarDataMap()
     m_hlayout->dumpBarDataMap();
 }
 
+void NotationScene::setExtraPreviewEvents(const EventWithSegmentMap& events)
+{
+    RG_DEBUG << "setExtraPreviewEvents" << events.size();
+    for (auto pair : events) {
+        const Event* e = pair.first;
+        const Segment* segment = pair.second;
+        if (m_additionalPreviewEvents.find(e) !=
+            m_additionalPreviewEvents.end()) continue; // already previewed
+
+        long pitch;
+        if (e->get<Int>(BaseProperties::PITCH, pitch)) {
+            long velocity = -1;
+            (void)(e->get<Int>(BaseProperties::VELOCITY, velocity));
+            if (!(e->has(BaseProperties::TIED_BACKWARD) &&
+                  e->get<Bool>(BaseProperties::TIED_BACKWARD))) {
+                playNote(*segment, pitch, velocity);
+            }
+        }
+    }
+    m_additionalPreviewEvents = events;
+}
+
 #if 0
 void
 NotationScene::setCurrentStaff(const timeT t)
