@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -103,6 +103,9 @@ public:
 
     NotationStaff *getStaffForSceneCoords(double x, int y) const;
 
+    // ??? The UI uses the term "Active" for this.  Evaluate each "current"
+    //     in here and see if it needs to be changed to "active" to match the
+    //     UI.  This one seems like it needs it.
     Segment *getCurrentSegment();
 
     bool segmentsContainNotes() const;
@@ -175,7 +178,7 @@ public:
     /// Remove any visible preview note
     void clearPreviewNote();
 
-    void playNote(Segment &segment, int pitch, int velocity = -1);
+    void playNote(const Segment &segment, int pitch, int velocity = -1);
 
     // unused bool constrainToSegmentArea(QPointF &scenePos);
 
@@ -197,8 +200,9 @@ public:
     bool isEventRedundant(Clef &clef, timeT time, Segment &seg) const;
     bool isEventRedundant(Key &key, timeT time, Segment &seg) const;
 
-    /// Return the segments about to be deleted if any
-    std::vector<Segment *> * getSegmentsDeleted() { return &m_segmentsDeleted; }
+    /// Return the segments about to be deleted if any.
+    const std::vector<Segment *> *getSegmentsDeleted()
+            { return &m_segmentsDeleted; }
 
     /// Return true if all segments in scene are about to be deleted
     /// (Editor needs to be closed)
@@ -227,6 +231,10 @@ public:
     void dumpVectors();
     void dumpBarDataMap();
 
+    // extra preview events
+    typedef std::map<const Event*, const Segment*> EventWithSegmentMap;
+    void setExtraPreviewEvents(const EventWithSegmentMap& events);
+
 signals:
     void sceneNeedsRebuilding();
 
@@ -384,6 +392,8 @@ private:
     std::map<int, std::string> m_trackLabels;
 
     QString m_highlightMode;
+
+    EventWithSegmentMap m_additionalPreviewEvents;
 };
 
 }
