@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -20,6 +20,7 @@
 
 #include "NotationTool.h"
 #include "NotationMouseEvent.h"
+#include "NotationScene.h"
 #include "base/Event.h"
 
 #include <QString>
@@ -99,7 +100,7 @@ public:
     static QString ToolName();
 
 signals:
-    void editElement(NotationStaff *, NotationElement *, bool advanced);
+    void editElement(NotationStaff *, NotationElement *);
 
 public slots:
     /**
@@ -142,7 +143,8 @@ protected:
 
     void drag(int x, int y, bool final);
 
-    EventSelection *getEventsInSelectionRect();
+    EventSelection *getEventsInSelectionRect
+        (NotationScene::EventWithSegmentMap* previewEvents);
 
     //--------------- Data members ---------------------------------
 
