@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -22,7 +22,6 @@
 #include "gui/general/SelectionManager.h"
 #include "gui/general/EditViewBase.h"
 #include "gui/widgets/ProgressBar.h"
-#include "gui/dialogs/TempoDialog.h"
 #include "base/NotationTypes.h"
 #include "base/Composition.h"
 
@@ -98,6 +97,15 @@ signals:
     void editTriggerSegment(int);
     void stepByStepTargetRequested(QObject *);
 
+public slots:
+    /// Note-on received asynchronously -- consider step-by-step editing
+    void slotInsertableNoteOnReceived(int pitch, int velocity);
+
+    /// Note-off received asynchronously -- consider step-by-step editing
+    void slotInsertableNoteOffReceived(int pitch, int velocity);
+
+    void slotStepByStepTargetRequested(QObject *);
+
 protected slots:
     /// Some change occurs and the whole scene have to be redrawn.
     /// First remove segments from our list when they are deleted from the
@@ -301,17 +309,10 @@ protected slots:
     void slotLoop();
     void slotLoopChanged();
 
-    /// Note-on received asynchronously -- consider step-by-step editing
-    void slotInsertableNoteOnReceived(int pitch, int velocity);
-
-    /// Note-off received asynchronously -- consider step-by-step editing
-    void slotInsertableNoteOffReceived(int pitch, int velocity);
-
     /// Note-on or note-off received asynchronously -- as above
     void slotInsertableNoteEventReceived(int pitch, int velocity, bool noteOn);
 
     void slotToggleStepByStep();
-    void slotStepByStepTargetRequested(QObject *);
 
     /// YG: Only for debug
     void slotDebugDump();
@@ -357,7 +358,7 @@ protected slots:
      * Triggered by the editElement() signal emitted by NotationSelector and
      * relayed through NotationWidget.
      */
-    void slotEditElement(NotationStaff *, NotationElement *, bool advanced);
+    void slotEditElement(NotationStaff *, NotationElement *);
 
     void slotExtendSelectionBackward();
     void slotExtendSelectionForward();
