@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -65,7 +65,9 @@ class NotePixmapFactory
 public:
     static const int NO_GRACE_SIZE = -1;
 
-    NotePixmapFactory(const QString& fontName = "", int size = -1, int graceSize = NO_GRACE_SIZE);
+    explicit NotePixmapFactory(const QString& fontName = "",
+                               int size = -1,
+                               int graceSize = NO_GRACE_SIZE);
     NotePixmapFactory(const NotePixmapFactory &);
     NotePixmapFactory &operator=(const NotePixmapFactory &);
     ~NotePixmapFactory();
