@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     This file is Copyright 2006
         Pedro Lopez-Cabanillas <plcl@users.sourceforge.net>
@@ -39,6 +39,7 @@
 #include "base/InstrumentStaticSignals.h"
 #include "gui/widgets/LineEdit.h"
 #include "base/MidiDevice.h"
+#include "base/Pitch.h"
 #include "gui/dialogs/PitchPickerDialog.h"
 #include "sound/PluginIdentifier.h"
 #include "gui/general/PresetHandlerDialog.h"
@@ -63,7 +64,6 @@
 #include <QMessageBox>
 #include <QPixmap>
 #include <QPushButton>
-#include <QSettings>
 #include <QString>
 #include <QWidget>
 
@@ -465,6 +465,17 @@ TrackParameterBox::setDocument(RosegardenDocument *doc)
 
     m_doc = doc;
 
+    // ??? We never remove this observer.  Add a dtor.  Might need to consider
+    //     a virtual dtor.  Have this class's dtor call removeObserver().
+    //
+    //     If that works, do the same for the following:
+    //       - CompositionModelImpl
+    //       - TrackButtons
+    //       - NotationScene
+    //       - others?
+    //
+    //     Test by checking the output for
+    //       [Composition] dtor: WARNING: x observers still extant:
     m_doc->getComposition().addObserver(this);
 
     // Populate color combo from the document colors.
@@ -1313,34 +1324,10 @@ TrackParameterBox::updateWidgets2()
             m_transpose->findText(QString("%1").arg(track->getTranspose())));
 
     // Pitch Lowest
-
-    QSettings settings;
-    settings.beginGroup(GeneralOptionsConfigGroup);
-    const int octaveBase = settings.value("midipitchoctave", -2).toInt() ;
-    settings.endGroup();
-
-    const bool includeOctave = false;
-
-    const Pitch lowest(track->getLowestPlayable(), Accidentals::NoAccidental);
-
-    // NOTE: this now uses a new, overloaded version of Pitch::getAsString()
-    // that explicitly works with the key of C major, and does not allow the
-    // calling code to specify how the accidentals should be written out.
-    //
-    // Separate the note letter from the octave to avoid undue burden on
-    // translators having to retranslate the same thing but for a number
-    // difference
-    QString tmp = QObject::tr(lowest.getAsString(includeOctave, octaveBase).c_str(), "note name");
-    tmp += tr(" %1").arg(lowest.getOctave(octaveBase));
-    m_lowest->setText(tmp);
+    m_lowest->setText(Pitch::toStringOctave(track->getLowestPlayable()));
 
     // Pitch Highest
-
-    const Pitch highest(track->getHighestPlayable(), Accidentals::NoAccidental);
-
-    tmp = QObject::tr(highest.getAsString(includeOctave, octaveBase).c_str(), "note name");
-    tmp += tr(" %1").arg(highest.getOctave(octaveBase));
-    m_highest->setText(tmp);
+    m_highest->setText(Pitch::toStringOctave(track->getHighestPlayable()));
 
     // Color
     // Note: We only update the combobox contents if there is an actual
