@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -257,9 +257,9 @@ MarkerEditor::slotUpdate()
 
     Composition &comp = m_doc->getComposition();
 
-    Composition::markercontainer markers = comp.getMarkers();
+    Composition::MarkerVector markers = comp.getMarkers();
 
-    Composition::markerconstiterator it;
+    Composition::MarkerVector::const_iterator it;
 
     QSettings settings;
     settings.beginGroup(MarkerEditorConfigGroup);
