@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -36,7 +36,6 @@
 #include "commands/segment/RenameTrackCommand.h"
 #include "document/RosegardenDocument.h"
 #include "document/CommandHistory.h"
-#include "gui/application/RosegardenMainWindow.h"
 #include "gui/general/GUIPalette.h"
 #include "gui/general/IconLoader.h"
 #include "gui/seqmanager/SequenceManager.h"
@@ -197,13 +196,6 @@ TrackButtons::TrackButtons(int trackCellHeight,
 
     // We never remove the observer so we should be ok here.
     RosegardenDocument::currentDocument->getComposition().addObserver(this);
-
-    // We do not care about RWM::documentLoaded() because if a new
-    // document is being loaded, we are going away.  A new TrackButtons
-    // instance is created for each new document.
-    //connect(RosegardenMainWindow::self(),
-    //            &RosegardenMainWindow::documentLoaded,
-    //        this, &TrackButtons::slotDocumentLoaded);
 }
 
 TrackButtons::~TrackButtons()
@@ -881,7 +873,7 @@ TrackButtons::populateInstrumentPopup(Instrument *thisTrackInstr, QMenu* instrum
                 deviceUsedByAnyone = true;
             else {
                 // For each Track...
-                for (Composition::trackcontainer::iterator trackIter =
+                for (Composition::TrackMap::iterator trackIter =
                          comp.getTracks().begin();
                      trackIter != comp.getTracks().end();
                      ++trackIter) {
@@ -936,7 +928,7 @@ TrackButtons::populateInstrumentPopup(Instrument *thisTrackInstr, QMenu* instrum
 
             // Search the tracks to see if anyone else is using this
             // instrument.
-            for (Composition::trackcontainer::const_iterator trackIter =
+            for (Composition::TrackMap::const_iterator trackIter =
                      comp.getTracks().begin();
                  trackIter != comp.getTracks().end();
                  ++trackIter) {
@@ -1315,6 +1307,10 @@ TrackButtons::makeButton(Track *track)
             m_clickedSigMapper, SLOT(map()));
 
 
+    // Squash it down to its smallest width.
+    trackHBox->setFixedWidth(hblayout->minimumSize().width());
+
+
     return trackHBox;
 }
 
