@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -63,7 +63,7 @@ class SegmentRect;
  * class works together with CompositionModelImpl to provide the composition
  * user interface (the segment canvas).
  */
-class CompositionView : public RosegardenScrollView 
+class CompositionView : public RosegardenScrollView
 {
     Q_OBJECT
 public:
@@ -215,6 +215,8 @@ public:
     /// See drawSplitLine().
     void hideSplitLine();
 
+    void setModeText(const QString& modeText);
+
 public slots:
 
     /// Handle TrackButtons scroll wheel events.
@@ -611,6 +613,9 @@ private:
 
     /// Performance testing.
     bool m_enableDrawing;
+    QString m_modeText;
+    bool m_modeTextChanged;
+    int m_modeTextWidth;
 };
 
 
