@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -23,6 +23,7 @@
 #include "misc/Debug.h"
 #include "base/Composition.h"
 #include "base/RealTime.h"
+#include "commands/segment/AddTempoChangeCommand.h"
 #include "commands/segment/AddTimeSignatureAndNormalizeCommand.h"
 #include "commands/segment/AddTimeSignatureCommand.h"
 #include "commands/segment/RemoveTempoChangeCommand.h"
@@ -94,17 +95,14 @@ TempoAndTimeSignatureEditor::TempoAndTimeSignatureEditor(timeT openTime)
 
     initMenu();
 
-    // Create frame and layout.
-    // ??? Why is this a QFrame?  QWidget should be enough.
-    m_frame = new QFrame(this);
-    m_frame->setMinimumSize(700, 300);
-    m_mainLayout = new QHBoxLayout(m_frame);
-    m_frame->setLayout(m_mainLayout);
-    setCentralWidget(m_frame);
+    // Create main widget and layout.
+    QWidget *mainWidget = new QWidget(this);
+    QHBoxLayout *mainLayout = new QHBoxLayout(mainWidget);
+    setCentralWidget(mainWidget);
 
     // Filter Group Box
-    m_filterGroup = new QGroupBox(tr("Filter"), m_frame);
-    m_mainLayout->addWidget(m_filterGroup);
+    m_filterGroup = new QGroupBox(tr("Filter"), mainWidget);
+    mainLayout->addWidget(m_filterGroup);
     QVBoxLayout *filterGroupLayout = new QVBoxLayout;
     m_filterGroup->setLayout(filterGroupLayout);
 
@@ -126,8 +124,8 @@ TempoAndTimeSignatureEditor::TempoAndTimeSignatureEditor(timeT openTime)
     filterGroupLayout->addStretch(1);
 
     // Tempo/Time Signature List
-    m_tableWidget = new QTableWidget(m_frame);
-    m_mainLayout->addWidget(m_tableWidget);
+    m_tableWidget = new QTableWidget(mainWidget);
+    mainLayout->addWidget(m_tableWidget);
     // Disable double-click editing of each field.
     m_tableWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
     m_tableWidget->setSelectionMode(QAbstractItemView::ExtendedSelection);
@@ -148,11 +146,13 @@ TempoAndTimeSignatureEditor::TempoAndTimeSignatureEditor(timeT openTime)
     // Make sure columns have a reasonable amount of space.
     m_tableWidget->setColumnWidth(0, 110);
     m_tableWidget->setColumnWidth(1, 120);
-    //m_tableWidget->setMinimumWidth(700);
+    m_tableWidget->setMinimumWidth(500);
     connect(m_tableWidget, &QTableWidget::cellDoubleClicked,
             this, &TempoAndTimeSignatureEditor::slotPopupEditor);
+    connect(m_tableWidget, &QTableWidget::itemSelectionChanged,
+            this, &TempoAndTimeSignatureEditor::slotItemSelectionChanged);
 
-    //m_frame->setMinimumSize(m_mainLayout->minimumSize());
+    mainWidget->setMinimumSize(mainLayout->minimumSize());
 
     // Update the list.
     updateTable();
@@ -229,6 +229,14 @@ TempoAndTimeSignatureEditor::updateTable()
         timeT midiTicks{0};
         Type itemType{Type::TimeSignature};
 
+        bool operator==(const Key &rhs) const
+        {
+            if (midiTicks != rhs.midiTicks)
+                return false;
+            if (itemType != rhs.itemType)
+                return false;
+            return true;
+        }
         bool operator<(const Key &rhs) const
         {
             if (midiTicks < rhs.midiTicks)
@@ -266,9 +274,9 @@ TempoAndTimeSignatureEditor::updateTable()
 
     // Preserve the "current item".
 
-    bool haveCurrentItem;
+    bool haveCurrentItem{false};
     Key currentItemKey;
-    int currentItemColumn;
+    int currentItemColumn{0};
 
     // Scope to avoid accidentally reusing currentItem after it is gone.
     {
@@ -277,7 +285,7 @@ TempoAndTimeSignatureEditor::updateTable()
         QTableWidgetItem *currentItem = m_tableWidget->currentItem();
         haveCurrentItem = currentItem;
         if (haveCurrentItem) {
-            int row = m_tableWidget->row(currentItem);
+            const int row = m_tableWidget->row(currentItem);
             currentItemColumn = m_tableWidget->column(currentItem);
 
             // We need the column 0 item since it is the only one with data.
@@ -289,6 +297,8 @@ TempoAndTimeSignatureEditor::updateTable()
         }
     }
 
+    bool haveSelection{false};
+
     // Recreate list.
 
     // Clear the list completely.
@@ -349,13 +359,41 @@ TempoAndTimeSignatureEditor::updateTable()
             item = new QTableWidgetItem(properties);
             m_tableWidget->setItem(row, 3, item);
 
+            // Create key.
+            Key key;
+            key.midiTicks = sig.first;
+            key.itemType = Type::TimeSignature;
+
             // Set current if it is the right one.
-            if (haveCurrentItem  &&
-                currentItemKey.itemType == Type::TimeSignature  &&
-                currentItemKey.midiTicks == sig.first) {
+            if (haveCurrentItem  &&  currentItemKey == key) {
                 item = m_tableWidget->item(row, currentItemColumn);
-                if (item)
-                    m_tableWidget->setCurrentItem(item);
+                if (item) {
+                    m_tableWidget->setCurrentItem(
+                            item, QItemSelectionModel::NoUpdate);
+                }
+            }
+
+            // There's a new item we need to select.
+            const bool newItemSelection = (m_newItemSelect  &&
+                    m_newItemType == Type::TimeSignature  &&
+                    m_newItemMIDITicks == sig.first);
+
+            // If we found it, only select the new item once.
+            if (newItemSelection)
+                m_newItemSelect = false;
+
+            // If this one was selected or is new, restore the selection.
+            if (selectionSet.find(key) != selectionSet.end()  ||
+                newItemSelection) {
+                // Select the entire row.
+                // For each column...
+                for (int col = 0; col < m_tableWidget->columnCount(); ++col) {
+                    QTableWidgetItem *item = m_tableWidget->item(row, col);
+                    if (!item)
+                        continue;
+                    item->setSelected(true);
+                }
+                haveSelection = true;
             }
         }
     }
@@ -429,51 +467,46 @@ TempoAndTimeSignatureEditor::updateTable()
             item = new QTableWidgetItem();
             m_tableWidget->setItem(row, 3, item);
 
+            // Create key.
+            Key key;
+            key.midiTicks = time;
+            key.itemType = Type::Tempo;
+
             // Set current if it is the right one.
-            if (haveCurrentItem  &&
-                currentItemKey.itemType == Type::Tempo  &&
-                currentItemKey.midiTicks == time) {
+            if (haveCurrentItem  &&  currentItemKey == key) {
                 item = m_tableWidget->item(row, currentItemColumn);
                 if (item)
-                    m_tableWidget->setCurrentItem(item);
+                    m_tableWidget->setCurrentItem(
+                            item, QItemSelectionModel::NoUpdate);
+            }
+
+            // There's a new item we need to select.
+            const bool newItemSelection = (m_newItemSelect  &&
+                    m_newItemType == Type::Tempo  &&
+                    m_newItemMIDITicks == time);
+
+            // If we found it, only select the new item once.
+            if (newItemSelection)
+                m_newItemSelect = false;
+
+            // If this one was selected or is new, restore the selection.
+            if (selectionSet.find(key) != selectionSet.end()  ||
+                newItemSelection) {
+                // Select the entire row.
+                // For each column...
+                for (int col = 0; col < m_tableWidget->columnCount(); ++col) {
+                    QTableWidgetItem *item = m_tableWidget->item(row, col);
+                    if (!item)
+                        continue;
+                    item->setSelected(true);
+                }
+                haveSelection = true;
             }
         }
     }
 
     m_tableWidget->sortItems(0, Qt::AscendingOrder);
 
-
-    // Restore Selection.
-
-    bool haveSelection{false};
-
-    // For each row...
-    for (int row = 0; row < m_tableWidget->rowCount(); ++row) {
-        QTableWidgetItem *item = m_tableWidget->item(row, 0);
-        if (!item)
-            continue;
-
-        // Create key.
-        Key key;
-        key.midiTicks = item->data(TimeRole).toLongLong();
-        key.itemType = (Type)item->data(TypeRole).toInt();
-
-        // Not selected?  Try the next.
-        if (selectionSet.find(key) == selectionSet.end())
-            continue;
-
-        // Select the entire row.
-        // For each column...
-        for (int col = 0; col < m_tableWidget->columnCount(); ++col) {
-            QTableWidgetItem *item = m_tableWidget->item(row, col);
-            if (!item)
-                continue;
-            item->setSelected(true);
-        }
-
-        haveSelection = true;
-    }
-
     if (haveSelection)
         enterActionState("have_selection");
     else
@@ -526,7 +559,7 @@ TempoAndTimeSignatureEditor::makeInitialSelection(timeT time)
     qApp->processEvents();
 
     // Make sure the item is visible.
-    m_tableWidget->scrollToItem(foundItem);
+    m_tableWidget->scrollToItem(foundItem, QAbstractItemView::PositionAtCenter);
 }
 
 void
@@ -575,7 +608,7 @@ TempoAndTimeSignatureEditor::select(timeT time, Type type)
     qApp->processEvents();
 
     // Make sure the item is visible.
-    m_tableWidget->scrollToItem(foundItem);
+    m_tableWidget->scrollToItem(foundItem, QAbstractItemView::PositionAtCenter);
 }
 
 Segment *
@@ -623,7 +656,7 @@ TempoAndTimeSignatureEditor::slotEditDelete()
 
     }
 
-    if (macroCommand->haveCommands())
+    if (macroCommand->hasCommands())
         CommandHistory::getInstance()->addCommand(macroCommand);
     else
         delete macroCommand;
@@ -775,27 +808,33 @@ TempoAndTimeSignatureEditor::initMenu()
 {
     setupBaseActions();
 
-    createAction("insert_tempo", SLOT(slotAddTempoChange()));
-    createAction("insert_timesig", SLOT(slotAddTimeSignatureChange()));
-    createAction("delete", SLOT(slotEditDelete()));
-    createAction("edit", SLOT(slotEditItem()));
-    createAction("select_all", SLOT(slotSelectAll()));
-    createAction("clear_selection", SLOT(slotClearSelection()));
-    createAction("tempo_help", SLOT(slotHelpRequested()));
-    createAction("help_about_app", SLOT(slotHelpAbout()));
+    createAction("insert_tempo",
+            &TempoAndTimeSignatureEditor::slotAddTempoChange);
+    createAction("insert_timesig",
+            &TempoAndTimeSignatureEditor::slotAddTimeSignatureChange);
+    createAction("delete", &TempoAndTimeSignatureEditor::slotEditDelete);
+    createAction("edit", &TempoAndTimeSignatureEditor::slotEditItem);
+    createAction("select_all", &TempoAndTimeSignatureEditor::slotSelectAll);
+    createAction("clear_selection",
+            &TempoAndTimeSignatureEditor::slotClearSelection);
+    createAction("tempo_help", &TempoAndTimeSignatureEditor::slotHelpRequested);
+    createAction("help_about_app", &TempoAndTimeSignatureEditor::slotHelpAbout);
 
     QAction *a;
-    a = createAction("time_musical", SLOT(slotViewMusicalTimes()));
+    a = createAction(
+            "time_musical", &TempoAndTimeSignatureEditor::slotViewMusicalTimes);
     a->setCheckable(true);
     if (a_timeMode.get() == (int)Composition::TimeMode::MusicalTime)
         a->setChecked(true);
 
-    a = createAction("time_real", SLOT(slotViewRealTimes()));
+    a = createAction(
+            "time_real", &TempoAndTimeSignatureEditor::slotViewRealTimes);
     a->setCheckable(true);
     if (a_timeMode.get() == (int)Composition::TimeMode::RealTime)
         a->setChecked(true);
 
-    a = createAction("time_raw", SLOT(slotViewRawTimes()));
+    a = createAction(
+            "time_raw", &TempoAndTimeSignatureEditor::slotViewRawTimes);
     a->setCheckable(true);
     if (a_timeMode.get() == (int)Composition::TimeMode::RawTime)
         a->setChecked(true);
@@ -846,15 +885,47 @@ TempoAndTimeSignatureEditor::slotViewRawTimes()
 }
 
 void
-TempoAndTimeSignatureEditor::popupEditor(timeT time, const Type type)
+TempoAndTimeSignatureEditor::popupEditor(const timeT time, const Type type)
 {
     switch (type)
     {
 
     case Type::Tempo:
-        // Launch the TempoDialog.
-        EditTempoController::self()->editTempo(
-                this, time, true /* timeEditable */);
+        {
+            RosegardenDocument *doc = RosegardenDocument::currentDocument;
+
+            TempoDialog tempoDialog(this, doc, true);
+            tempoDialog.setTempoPosition(time);
+
+            if (tempoDialog.exec() != QDialog::Accepted)
+                return;
+
+            // Let updateTable() know it needs to select this new item.
+            m_newItemSelect = true;
+            m_newItemMIDITicks = tempoDialog.getTime();
+            m_newItemType = Type::Tempo;
+
+            Composition &comp = doc->getComposition();
+
+            const int index = comp.getTempoChangeNumberAt(time);
+            if (index < 0)
+                return;
+
+            MacroCommand *macro = new MacroCommand(tr("Edit Tempo Change"));
+
+            // Remove the old.
+            macro->addCommand(new RemoveTempoChangeCommand(&comp, index));
+
+            // Add the new.
+            macro->addCommand(new AddTempoChangeCommand(
+                    &comp,
+                    tempoDialog.getTime(),
+                    tempoDialog.getTempo(),
+                    tempoDialog.getTargetTempo()));
+
+            CommandHistory::getInstance()->addCommand(macro);
+        }
+
         break;
 
     case Type::TimeSignature:
@@ -865,23 +936,33 @@ TempoAndTimeSignatureEditor::popupEditor(timeT time, const Type type)
 
             TimeSignatureDialog dialog(this, &composition, time, sig, true);
 
-            if (dialog.exec() == QDialog::Accepted) {
+            if (dialog.exec() != QDialog::Accepted)
+                return;
 
-                time = dialog.getTime();
+            timeT newTime = dialog.getTime();
 
-                if (dialog.shouldNormalizeRests()) {
-                    CommandHistory::getInstance()->addCommand(
-                            new AddTimeSignatureAndNormalizeCommand(
-                                    &composition,
-                                    time,
-                                    dialog.getTimeSignature()));
-                } else {
-                    CommandHistory::getInstance()->addCommand(
-                            new AddTimeSignatureCommand(
-                                    &composition,
-                                    time,
-                                    dialog.getTimeSignature()));
-                }
+            // Let updateTable() know it needs to select this new item.
+            m_newItemSelect = true;
+            m_newItemMIDITicks = newTime;
+            m_newItemType = Type::TimeSignature;
+
+            // ??? Why don't we delete the old?  If the user changes the time,
+            //     they will end up with a duplicate time signature change.
+            //     Does deleting the old make a mess of things?  If so, then
+            //     perhaps we should lock time on the TimeSignatureDialog.
+
+            if (dialog.shouldNormalizeRests()) {
+                CommandHistory::getInstance()->addCommand(
+                        new AddTimeSignatureAndNormalizeCommand(
+                                &composition,
+                                newTime,
+                                dialog.getTimeSignature()));
+            } else {
+                CommandHistory::getInstance()->addCommand(
+                        new AddTimeSignatureCommand(
+                                &composition,
+                                newTime,
+                                dialog.getTimeSignature()));
             }
 
             break;
@@ -926,5 +1007,16 @@ TempoAndTimeSignatureEditor::slotDocumentModified(bool /*modified*/)
     updateTable();
 }
 
+void
+TempoAndTimeSignatureEditor::slotItemSelectionChanged()
+{
+    const bool haveSelection = !m_tableWidget->selectedItems().empty();
+
+    if (haveSelection)
+        enterActionState("have_selection");
+    else
+        leaveActionState("have_selection");
+}
+
 
 }
