@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -31,7 +31,7 @@
 #include <QToolBar>
 #include <QToolButton>
 
-namespace Rosegarden 
+namespace Rosegarden
 {
 
 ActionFileClient::ActionFileClient() :
@@ -158,7 +158,7 @@ ActionFileClient::findMenu(QString menuName)
             RG_WARNING << "WARNING: ActionFileClient(\"" << obj->objectName()
                       << "\")::findMenu: No such menu (wrapper) as \"" << menuName << "\"";
         }
-    }            
+    }
     return m;
 }
 
@@ -227,6 +227,16 @@ ActionFileClient::enableAutoRepeat(
     button->setAutoRepeat(true);
 }
 
-
+QAction* ActionFileClient::makeAction(const QString& actionName)
+{
+    QObject *obj = dynamic_cast<QObject *>(this);
+    if (!obj) {
+        RG_WARNING << "ERROR: ActionFileClient::createAction: ActionFileClient subclass is not a QObject";
+        return nullptr;
+    }
+    QAction *action = new QAction(obj);
+    action->setObjectName(actionName);
+    return action;
 }
 
+}
