@@ -1,7 +1,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -13,11 +13,12 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef EDITTEMPOCONTROLLER_H
-#define EDITTEMPOCONTROLLER_H
+#ifndef RG_EDITTEMPOCONTROLLER_H
+#define RG_EDITTEMPOCONTROLLER_H
+
+#include "gui/dialogs/TempoDialog.h"
 
 #include <QObject>
-#include "gui/dialogs/TempoDialog.h"
 
 
 namespace Rosegarden
@@ -30,8 +31,9 @@ class Composition;
 
 /// A collection of tempo and time signature dialogs and commands.
 /**
- * @brief The EditTempoController class centralizes code for tempo edition
- * It is called both by the Tempo Ruler instances, by the main window (for shortcuts, and for the transport dialog)
+ * The EditTempoController class centralizes code for tempo edition It is
+ * called both by the Tempo Ruler instances, by the main window (for shortcuts,
+ * and for the transport dialog)
  *
  * ??? It's hard to think of an appropriate name for this assorted collection of
  *     dialogs and commands.  Therefore it is difficult to justify its
@@ -43,38 +45,36 @@ class Composition;
 class EditTempoController : public QObject
 {
     Q_OBJECT
+
 public:
-    /**
-     * Constructor. Called by the mainwindow
-     */
-    explicit EditTempoController(QObject *parent = nullptr);
 
-    /// Make sure the current document is used.
+    /// Singleton instance.
     /**
-     * ??? Should be able to safely switch to RosegardenDocument::currentDocument
-     *     and get rid of this.
-     */
-    void setDocument(RosegardenDocument *doc);
-
-    /**
-     * ??? Make this a proper Singleton so that we don't have to jump
-     *     through so many hoops.  Create on first call to Self.  Maintain
-     *     the instance internally.  Private ctor.  Etc...
+     * Returns the unique instance of EditTempoController, created by
+     * RosegardenMainWindow.  This is only an acceptable hack because
+     * RosegardenMainWindow itself is a Singleton.  The alternative is to pass
+     * this down from the RosegardenMainWindow to:
      *
-     * Returns the unique instance of EditTempoController, created by the mainwindow.
-     * This is only an acceptable hack because the mainwindow itself is a singleton.
-     * The alternative is to pass this down from the mainwindow to
-     * MatrixView -> MatrixWidget -> TempoRuler
-     * NotationView -> NotationWidget -> TempoRuler
-     * RosegardeMainViewWidget -> TrackEditor -> TempoRuler
-     * so we might as well first collect more controllers into a single object to pass down to all these.
+     *   - MatrixView -> MatrixWidget -> TempoRuler
+     *   - NotationView -> NotationWidget -> TempoRuler
+     *   - RosegardeMainViewWidget -> TrackEditor -> TempoRuler
+     *
+     * So we might as well first collect more controllers into a single object
+     * to pass down to all these.
      */
     static EditTempoController *self();
 
-    void emitEditTempos(timeT time) { emit editTempos(time); }
+    /// Make sure the current document is used.
+    /**
+     * ??? Should be able to safely switch to
+     *     RosegardenDocument::currentDocument and get rid of this.
+     */
+    void setDocument(RosegardenDocument *doc);
+
+    void emitEditTempos(timeT time)  { emit editTempos(time); }
 
     /// Launches a TempoDialog.
-    void editTempo(QWidget *parent, timeT atTime, bool timeEditable = false);
+    void editTempo(QWidget *parent, timeT atTime, bool timeEditable);
     /// Launches a TimeSignatureDialog.
     void editTimeSignature(QWidget *parent, timeT time);
     /// Assembles and executes a command to move the tempo at oldTime to newTime.
@@ -84,19 +84,27 @@ public:
     void deleteTempoChange(timeT time);
 
 signals:
+
     void editTempos(timeT time);
 
 public slots:
+
     void changeTempo(timeT time,
-                         tempoT value,
-                         tempoT target,
-                         TempoDialog::TempoDialogAction action);
+                     tempoT value,
+                     tempoT target,
+                     TempoDialog::TempoDialogAction action);
 
 private:
-    RosegardenDocument *m_doc;
-    Composition *m_composition;
+
+    /// Singleton.
+    EditTempoController()  { }
+
+    RosegardenDocument *m_doc{nullptr};
+    Composition *m_composition{nullptr};
+
 };
 
+
 }
 
-#endif // EDITTEMPOCONTROLLER_H
+#endif
