@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -23,7 +23,7 @@
 #include "misc/Debug.h"
 #include "misc/Strings.h"
 #include "base/MidiProgram.h"
-#include "gui/general/MidiPitchLabel.h"
+#include "base/Pitch.h"
 #include "PitchRuler.h"
 #include <QColor>
 #include <QEvent>
@@ -95,12 +95,12 @@ void PercussionPitchRuler::paintEvent(QPaintEvent*)
 
     for (int i = 0; i < extent; ++i) {
 
-        MidiPitchLabel label(minPitch + i);
+        QString label = Pitch::toStringOctave(minPitch + i);
         std::string key = m_mapping->getMapForKeyName(minPitch + i);
         //RG_DEBUG << "PercussionPitchRuler::paintEvent()" << i << ": " << label.getQString() << ": " << key;
 
         int yi = (extent - i - 1) * (m_lineSpacing + 1) + offset;
-        paint.drawText(2, yi, label.getQString());
+        paint.drawText(2, yi, label);
 
         if (i != m_highlightPitch) {
             // Draw an unhighlighted note
