@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -18,10 +18,11 @@
 #ifndef RG_TEMPORULER_H
 #define RG_TEMPORULER_H
 
-#include "gui/dialogs/TempoDialog.h"
 #include "gui/general/ActionFileClient.h"
 
+#include "base/Composition.h" // for tempoT!?
 #include "base/Event.h"
+#include "base/TimeT.h"
 
 #include <QFont>
 #include <QFontMetrics>
@@ -123,8 +124,8 @@ private:
     bool m_dragFine;
     int  m_clickX;
 
-    timeT  m_dragStartTime;
-    timeT  m_dragPreviousTime;
+    timeT  m_dragStartTime{0};
+    timeT  m_dragPreviousTime{0};
     tempoT m_dragStartTempo;
     tempoT m_dragStartTarget;
     tempoT m_dragOriginalTempo;
