@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -87,8 +87,8 @@ SequenceManager::SequenceManager() :
     m_addedSegments(),
     m_removedSegments(),
     m_shownOverrunWarning(false),
-    m_reportTimer(nullptr),
-    m_canReport(true),
+    //m_reportTimer(nullptr),
+    //m_canReport(true),
     m_transportStatus(STOPPED),
     m_lastRewoundAt(clock()),
     m_countdownDialog(nullptr),
@@ -387,10 +387,10 @@ SequenceManager::record(bool countIn)
     // a valid audio record path and a working audio subsystem before
     // we go any further
 
-    const Composition::recordtrackcontainer &recordTracks =
+    const Composition::TrackIdSet &recordTracks =
         comp.getRecordTracks();
 
-    for (Composition::recordtrackcontainer::const_iterator i =
+    for (Composition::TrackIdSet::const_iterator i =
                 recordTracks.begin();
             i != recordTracks.end(); ++i) {
 
@@ -485,7 +485,7 @@ punchin:
         bool haveMIDIInstrument = false;
         //TrackId recordMIDITrack = 0;
 
-        for (Composition::recordtrackcontainer::const_iterator i =
+        for (Composition::TrackIdSet::const_iterator i =
                     comp.getRecordTracks().begin();
                 i != comp.getRecordTracks().end(); ++i) {
 
@@ -555,7 +555,7 @@ punchin:
 
         if (haveMIDIInstrument) {
             // For each recording segment...
-            for (Composition::recordtrackcontainer::const_iterator i =
+            for (Composition::TrackIdSet::const_iterator i =
                         comp.getRecordTracks().begin(); i != comp.getRecordTracks().end(); ++i) {
                 // Get the Instrument for this Track
                 InstrumentId iid = comp.getTrackById(*i)->getInstrument();
@@ -828,10 +828,12 @@ SequenceManager::processAsynchronousMidi(const MappedEventList &mC,
                     if (handling)
                         continue;
 
+#if 0
                     if (!m_canReport) {
                         RG_DEBUG << "processAsynchronousMidi(): Not reporting it to user just yet";
                         continue;
                     }
+#endif
 
                     if ((*i)->getData1() == MappedEvent::FailureALSACallFailed) {
 
@@ -927,6 +929,7 @@ SequenceManager::processAsynchronousMidi(const MappedEventList &mC,
 
                     }
 
+#if 0
                     // Turn off the report flag and set off a one-shot
                     // timer for 5 seconds.
                     if (!m_reportTimer->isActive()) {
@@ -938,6 +941,7 @@ SequenceManager::processAsynchronousMidi(const MappedEventList &mC,
                         m_reportTimer->setSingleShot(true);
                         m_reportTimer->start(5000);
                     }
+#endif
                 }
             } else {  // Neither playing nor recording.
                 //StartupLogo::hideIfStillThere();
@@ -959,35 +963,7 @@ SequenceManager::processAsynchronousMidi(const MappedEventList &mC,
                             RosegardenMainWindow::self(), "",
                             tr("The JACK Audio subsystem has stopped Rosegarden from processing audio, probably because of a processing overload.\nAn attempt to restart the audio service has been made, but some problems may remain.\nQuitting other running applications may improve Rosegarden's performance."));
 
-                    } else if ((*i)->getData1() == MappedEvent::WarningImpreciseTimer &&
-                               shouldWarnForImpreciseTimer()) {
-
-                        RG_WARNING << "Rosegarden: WARNING: No accurate sequencer timer available";
-
-#if 0
-                        //StartupLogo::hideIfStillThere();
-
-                        //RosegardenMainWindow::self()->awaitDialogClearance();
-
-                        // This is to avoid us ever showing the same
-                        // dialog more than once during a single run
-                        // of the program -- it's quite separate from
-                        // the suppression function
-                        static bool showTimerWarning = true;
-
-                        if (showTimerWarning) {
-                            // ??? Um.  Why?  This just goes out of scope.
-                            informativeText =
-                                    tr("<p>Rosegarden was unable to find a high-resolution timing source for MIDI performance.</p><p>This may mean you are using a Linux system with the kernel timer resolution set too low.  Please contact your Linux distributor for more information.</p><p>Some Linux distributors already provide low latency kernels, see the <a style=\"color:gold\" href=\"http://www.rosegardenmusic.com/wiki/low-latency_kernels\">Rosegarden website</a> for instructions.</p>");
-
-                            // Don't show again during this run.
-                            // ??? Don't show what?
-                            showTimerWarning = false;
-                        }
-#endif
-
-                    } else if ((*i)->getData1() == MappedEvent::WarningImpreciseTimerTryRTC &&
-                               shouldWarnForImpreciseTimer()) {
+                    } else if ((*i)->getData1() == MappedEvent::WarningImpreciseTimerTryRTC) {
 
                         RG_WARNING << "WARNING: No accurate sequencer timer available.";
 
@@ -1002,7 +978,7 @@ SequenceManager::processAsynchronousMidi(const MappedEventList &mC,
                             emit sendWarning(
                                     WarningWidget::Timer,
                                     tr("<h3>System timer resolution is too low!</h3>"),
-                                    tr("<p>Rosegarden was unable to find a high-resolution timing source for MIDI performance.</p><p>You may be able to solve this problem by loading the RTC timer kernel module.  To do this, try running <b>sudo modprobe snd-rtctimer</b> in a terminal window and then restarting Rosegarden.</p><p>Alternatively, check whether your Linux distributor provides a multimedia-optimized kernel.  See the <a style=\"color:gold\"  href=\"http://www.rosegardenmusic.com/wiki/low-latency_kernels\">Rosegarden website</a> for notes about this.</p>"));
+                                    tr("<p>Rosegarden was unable to find a high-resolution timing source for MIDI performance.</p><p>Check whether your Linux distribution provides a multimedia-optimized kernel.  See the <a style=\"color:gold\" href=\"http://www.rosegardenmusic.com/wiki/low-latency_kernels\">Rosegarden website</a> for notes about this.</p>"));
 
                             // Don't show again during this run.
                             showAltTimerWarning = false;
@@ -1306,7 +1282,7 @@ void SequenceManager::populateCompositionMapper()
         segmentAdded(*i);
     }
 
-    for (Composition::triggersegmentcontaineriterator i =
+    for (Composition::TriggerSegmentSet::iterator i =
                 comp.getTriggerSegments().begin();
          i != comp.getTriggerSegments().end(); ++i) {
         m_triggerSegments.insert(SegmentRefreshMap::value_type
@@ -1420,7 +1396,7 @@ void SequenceManager::refresh()
     SegmentRefreshMap newTriggerMap;
 
     // For each trigger Segment in the composition
-    for (Composition::triggersegmentcontaineriterator i =
+    for (Composition::TriggerSegmentSet::iterator i =
              comp.getTriggerSegments().begin();
          i != comp.getTriggerSegments().end(); ++i) {
 
@@ -1507,21 +1483,26 @@ void SequenceManager::segmentAdded(const Composition*, Segment* s)
     m_addedSegments.push_back(s);
 }
 
-void SequenceManager::segmentRemoved(const Composition*, Segment* s)
+void SequenceManager::segmentRemoved(const Composition *comp, Segment *segment)
 {
-    RG_DEBUG << "segmentRemoved(" << s << ")";
+    RG_DEBUG << "segmentRemoved(" << segment << ")";
+
+    // Triggered Segment?
+    if (comp->getTriggerSegmentId(segment) != -1) {
+        m_triggerSegments.erase(segment);
+        return;
+    }
 
     // !!! WARNING !!!
-    // The segment pointer "s" is about to be deleted by
+    // The segment pointer "segment" is about to be deleted by
     // Composition::deleteSegment(Composition::iterator).  After this routine
     // ends, this pointer cannot be dereferenced.
-    m_removedSegments.push_back(s);
+    m_removedSegments.push_back(segment);
 
-    std::vector<Segment*>::iterator i =
-        find(m_addedSegments.begin(), m_addedSegments.end(), s);
-    if (i != m_addedSegments.end()) {
-        m_addedSegments.erase(i);
-    }
+    std::vector<Segment *>::const_iterator segmentIter =
+            find(m_addedSegments.begin(), m_addedSegments.end(), segment);
+    if (segmentIter != m_addedSegments.end())
+        m_addedSegments.erase(segmentIter);
 }
 
 void SequenceManager::segmentRepeatChanged(const Composition*, Segment* s, bool repeat)
@@ -1779,35 +1760,25 @@ void SequenceManager::tempoChanged(const Composition *c)
 }
 
 void
-SequenceManager::sendTransportControlStatuses()
+SequenceManager::sendPreferences()
 {
-    // ??? static function.  Where does this really belong?  I suspect
-    //     RosegardenSequencer.
-
     QSettings settings;
-    settings.beginGroup( SequencerOptionsConfigGroup );
+    settings.beginGroup(SequencerOptionsConfigGroup);
 
-    // Get the settings values
-    //
-    bool jackTransport = qStrToBool( settings.value("jacktransport", "false" ) ) ;
-    bool jackMaster = qStrToBool( settings.value("jackmaster", "false" ) ) ;
-
-    int mmcMode = settings.value("mmcmode", 0).toInt() ;
-    int mtcMode = settings.value("mtcmode", 0).toInt() ;
-
-    int midiClock = settings.value("midiclock", 0).toInt() ;
-    bool midiSyncAuto = qStrToBool( settings.value("midisyncautoconnect", "false" ) ) ;
 
     // Send JACK transport
-    //
+
+    const bool jackTransport = qStrToBool(settings.value("jacktransport", "false"));
+    const bool jackSource = qStrToBool(settings.value("jackmaster", "false"));
+
     MidiByte jackValue{0};
-    if (jackTransport && jackMaster)
-        jackValue = 2;
+    if (jackTransport && jackSource)
+        jackValue = 2;  // On and source.
     else {
         if (jackTransport)
-            jackValue = 1;
+            jackValue = 1;  // On and follow.
         else
-            jackValue = 0;
+            jackValue = 0;  // Off.
     }
 
     MappedEvent mEjackValue;
@@ -1819,7 +1790,8 @@ SequenceManager::sendTransportControlStatuses()
 
 
     // Send MMC transport
-    //
+
+    const int mmcMode = settings.value("mmcmode", 0).toInt();
     MappedEvent mEmmcValue;
     mEmmcValue.setInstrumentId(MidiInstrumentBase);  // ??? needed?
     mEmmcValue.setType(MappedEvent::SystemMMCTransport);
@@ -1829,7 +1801,8 @@ SequenceManager::sendTransportControlStatuses()
 
 
     // Send MTC transport
-    //
+
+    const int mtcMode = settings.value("mtcmode", 0).toInt();
     MappedEvent mEmtcValue;
     mEmtcValue.setInstrumentId(MidiInstrumentBase);  // ??? needed?
     mEmtcValue.setType(MappedEvent::SystemMTCTransport);
@@ -1839,7 +1812,8 @@ SequenceManager::sendTransportControlStatuses()
 
 
     // Send MIDI Clock
-    //
+
+    const int midiClock = settings.value("midiclock", 0).toInt();
     MappedEvent mEmidiClock;
     mEmidiClock.setInstrumentId(MidiInstrumentBase);  // ??? needed?
     mEmidiClock.setType(MappedEvent::SystemMIDIClock);
@@ -1849,7 +1823,9 @@ SequenceManager::sendTransportControlStatuses()
 
 
     // Send MIDI Sync Auto-Connect
-    //
+
+    const bool midiSyncAuto =
+            qStrToBool(settings.value("midisyncautoconnect", "false"));
     MappedEvent mEmidiSyncAuto;
     mEmidiSyncAuto.setInstrumentId(MidiInstrumentBase);  // ??? needed?
     mEmidiSyncAuto.setType(MappedEvent::SystemMIDISyncAuto);
@@ -1857,7 +1833,6 @@ SequenceManager::sendTransportControlStatuses()
 
     StudioControl::sendMappedEvent(mEmidiSyncAuto);
 
-    settings.endGroup();
 }
 
 void
@@ -1908,19 +1883,6 @@ SequenceManager::setExportWavFile(const QString& fileName)
     m_exportTimer->start(50);
 }
 
-bool
-SequenceManager::shouldWarnForImpreciseTimer()
-{
-    const QString timer =
-            RosegardenSequencer::getInstance()->getCurrentTimer();
-
-    // If no specific timer has been chosen by the user, do warnings
-    if (timer == "(auto)"  ||  timer == "")
-        return true;
-    else  // The user has chosen a specific timer, leave them alone.
-        return false;
-}
-
 // Return a new metaiterator on the current composition (suitable
 // for MidiFile)
 MappedBufMetaIterator *
