@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -30,6 +30,8 @@
 #include <QWindow>
 #include <QCloseEvent>
 
+#include <set>
+
 #include <lilv/lilv.h>
 #include <lv2/ui/ui.h>
 #include <lv2/instance-access/instance-access.h>
@@ -38,6 +40,11 @@
 
 namespace
 {
+
+    // some plugins call the writeFn even after a cleanup so keep a
+    // track of all objects to avoid calls for deleted windows
+    static std::set<Rosegarden::AudioPluginLV2GUIWindow*> activeWindows;
+
     /// For LV2UI_Descriptor::instantiate().
     void writeFn(LV2UI_Controller controller,
                  uint32_t port_index,
@@ -47,6 +54,7 @@ namespace
     {
         Rosegarden::AudioPluginLV2GUIWindow* ap =
             static_cast<Rosegarden::AudioPluginLV2GUIWindow*>(controller);
+        if (activeWindows.find(ap) == activeWindows.end()) return;
         ap->portChange(port_index, buffer_size, port_protocol, buffer);
     }
 
@@ -69,6 +77,7 @@ namespace
     {
         Rosegarden::AudioPluginLV2GUIWindow* ap =
             static_cast<Rosegarden::AudioPluginLV2GUIWindow*>(controller);
+        if (activeWindows.find(ap) == activeWindows.end()) return;
         ap->uiClosed();
     }
 
@@ -96,7 +105,9 @@ AudioPluginLV2GUIWindow::AudioPluginLV2GUIWindow
     m_titleStdString(title.toStdString()),
     m_shutdownRequested(false)
 {
-    RG_DEBUG << "create window" << id << m_uiType << m_title;
+    activeWindows.insert(this);
+    RG_DEBUG << "create window" <<
+        id << m_uiType << m_title << activeWindows.size();
     setWindowTitle(m_title);
 
     // Create the idle timer for this window.
@@ -196,6 +207,7 @@ AudioPluginLV2GUIWindow::AudioPluginLV2GUIWindow
 
     RG_DEBUG << "handle:" << m_handle << "widget:" << m_widget;
 
+#ifdef HAVE_GTK2
     if (m_uiType == AudioPluginLV2GUI::GTK) {
         LV2Gtk* lv2gtk = LV2Gtk::getInstance();
         m_gwidget = lv2gtk->getWidget(m_widget, this);
@@ -218,11 +230,15 @@ AudioPluginLV2GUIWindow::AudioPluginLV2GUIWindow
         RG_DEBUG << "got gtk window" << m_parentWindow <<
             m_parentWindow->parent();
     }
+#else
+    RG_DEBUG << "gtk2 UI not available";
+#endif
 }
 
 AudioPluginLV2GUIWindow::~AudioPluginLV2GUIWindow()
 {
     RG_DEBUG << "~AudioPluginLV2GUIWindow";
+    activeWindows.erase(this);
     m_timer->stop();
     m_lv2II = nullptr;
 }
@@ -307,8 +323,10 @@ void AudioPluginLV2GUIWindow::closeEvent(QCloseEvent* event)
     // tell the ui to tidy up
     if (m_parentWindow) m_parentWindow->setParent(nullptr);
 
+#ifdef HAVE_GTK2
     LV2Gtk* lv2gtk = LV2Gtk::getInstance();
     lv2gtk->deleteWidget(m_gwidget);
+#endif
 
     // this will cause this object to be deleted
     m_lv2Gui->closeUI();
