@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -1891,10 +1891,10 @@ bool BankEditorDialog::tracksUsingBank(const MidiBank& bank,
 
     Composition &composition =
             RosegardenDocument::currentDocument->getComposition();
-    const Composition::trackcontainer &tracks = composition.getTracks();
+    const Composition::TrackMap &tracks = composition.getTracks();
 
     // For each Track in the Composition...
-    for (const Composition::trackcontainer::value_type &pair : tracks) {
+    for (const Composition::TrackMap::value_type &pair : tracks) {
         const Track *track = pair.second;
         if (!track)
             continue;
