@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -35,12 +35,5 @@ MidiMixerVUMeter::MidiMixerVUMeter(QWidget *parent,
     setAlignment(Qt::AlignCenter);
 }
 
-void
-MidiMixerVUMeter::meterStart()
-{}
-
-void
-MidiMixerVUMeter::meterStop()
-{}
 
 }
