@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -88,16 +88,10 @@ TimeWidget::init(bool editable)
     bool savedEditable = editable;
     editable = true;
 
-    QGridLayout *layout = new QGridLayout;
+    QGridLayout *layout = new QGridLayout(this);
     layout->setSpacing(5);
     QLabel *label = nullptr;
 
-    // When ThornStyle is not used, the title of the QGroupBox is
-    // misplaced (Bug #1678). The following line fixes it.
-    // This is more a hack than a real fix as I'm unable to find the cause
-    // of the problem, but it works.
-    setStyle(nullptr);
-
     if (m_isDuration) {
 
         label = new QLabel(tr("Note:"));
@@ -299,8 +293,6 @@ TimeWidget::init(bool editable)
         m_tempo = nullptr;
     }
 
-    setLayout(layout);
-
     if (!savedEditable) {
         if (m_note)
             m_note ->setEnabled(false);
