@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -50,6 +50,9 @@ namespace Preferences
     ROSEGARDENPRIVATE_EXPORT int getTheme();
     ROSEGARDENPRIVATE_EXPORT bool getThorn();
 
+    void setMIDIPitchOctave(int value);
+    int getMIDIPitchOctave();
+
     void setSendProgramChangesWhenLooping(bool value);
     bool getSendProgramChangesWhenLooping();
 
@@ -70,6 +73,9 @@ namespace Preferences
     void setAdvancedLooping(bool value);
     bool getAdvancedLooping();
 
+    void setJACKStopAtAutoStop(bool value);
+    bool getJACKStopAtAutoStop();
+
     // AudioFileLocationDialog settings
 
     void setAudioFileLocationDlgDontShow(bool value);
@@ -82,12 +88,15 @@ namespace Preferences
     void setCustomAudioLocation(const QString &location);
     QString getCustomAudioLocation();
 
+
+    // Enable/Disable CPU load checks.
     void setJACKLoadCheck(bool value);
     bool getJACKLoadCheck();
 
     void setShowNoteNames(bool value);
     bool getShowNoteNames();
 
+
     // Experimental
 
     bool getBug1623();
@@ -96,6 +105,9 @@ namespace Preferences
     void setLV2(bool value);
     bool getLV2();
 
+    void setDynamicDrag(bool value);
+    bool getDynamicDrag();
+
     void setAutoChannels(bool value);
     bool getAutoChannels();
 
@@ -104,6 +116,11 @@ namespace Preferences
 
     void setSMFExportPPQN(int value);
     int getSMFExportPPQN();
+
+    // matrix editor note constraint
+    void setMatrixConstrainNotes(bool value);
+    bool getMatrixConstrainNotes();
+
 }
 
 
