@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -69,7 +69,7 @@ RosegardenSequencer::RosegardenSequencer() :
     m_loopEnd(0, 0),
     m_studio(new MappedStudio()),
     m_transportToken(1),
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
     m_isEndOfCompReached(false)
 #else
     m_isEndOfCompReached(false),
@@ -973,7 +973,7 @@ RosegardenSequencer::disconnectMappedObject(int id)
 unsigned int
 RosegardenSequencer::getSampleRate() const
 {
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
     QMutexLocker locker(const_cast<QRecursiveMutex *>(&m_mutex));
 #else
     QMutexLocker locker(const_cast<QMutex *>(&m_mutex));
@@ -1563,9 +1563,9 @@ RosegardenSequencer::transportChange(TransportRequest request)
     SEQUENCER_DEBUG << "RosegardenSequencer::transportChange: " << request;
 #endif
     if (request == TransportNoChange)
-        return m_transportToken;
+        return m_transportToken;  // No change at all.
     else
-        return m_transportToken + 1;
+        return m_transportToken + 1;  // Start or Stop.
 }
 
 RosegardenSequencer::TransportToken
@@ -1580,10 +1580,10 @@ RosegardenSequencer::transportJump(TransportRequest request,
 #ifdef DEBUG_ROSEGARDEN_SEQUENCER
     SEQUENCER_DEBUG << "RosegardenSequencer::transportJump: " << request << ", " << rt;
 #endif
-    if (request == TransportNoChange)
-        return m_transportToken + 1;
+    if (request == TransportNoChange  ||  request == TransportJumpToTime)
+        return m_transportToken + 1;  // Just a jump.
     else
-        return m_transportToken + 2;
+        return m_transportToken + 2;  // Jump and Start.
 }
 
 bool
@@ -1656,5 +1656,18 @@ bool RosegardenSequencer::isLooping() const
     return m_withinLoop  &&  m_loopStart != m_loopEnd;
 }
 
+QString RosegardenSequencer::transportRequestToString(TransportRequest request)
+{
+    if (request < 0  ||  request > TransportStopAtTime)
+        return "???";
+
+    static const std::vector<QString> requests{
+        "NoChange", "Stop", "Start", "Play", "Record", "JumpToTime",
+        "StartAtTime", "StopAtTime"
+    };
+
+    return requests[request];
+}
+
 
 }
