@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -24,7 +24,7 @@
 #include "base/MidiDevice.h"
 
 #include <QMutex>
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
 #include <QRecursiveMutex>
 #endif
 #include <QObject>
@@ -349,6 +349,8 @@ public:
         TransportStartAtTime, // time arg required
         TransportStopAtTime // time arg required
     };
+    // For debug.  Do not remove.
+    static QString transportRequestToString(TransportRequest request);
 
     /// Called by RosegardenMainWindow::slotHandleInputs().
     /**
@@ -538,6 +540,12 @@ private:
 
     typedef std::pair<TransportRequest, RealTime> TransportPair;
     std::deque<TransportPair> m_transportRequests;
+    /// Serial number used to detect completion of processing across threads.
+    /**
+     * ??? If someone calls one of the functions that returns a token (e.g.
+     *     transportChange()) before processing is complete, this serial number
+     *     will be out of sync.  That will cause false reporting of completion.
+     */
     TransportToken m_transportToken;
 
     /// UNUSED
@@ -547,7 +555,7 @@ private:
      */
     bool m_isEndOfCompReached;
 
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
     QRecursiveMutex m_mutex;
 #else
     QMutex m_mutex;
