@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -30,7 +30,9 @@
 #include "JackDriver.h"
 #endif
 
-#include <alsa/asoundlib.h> // ALSA
+// Forward declares from alsa/asoundlib.h
+typedef struct snd_seq_event snd_seq_event_t;
+typedef struct _snd_seq snd_seq_t;
 
 #include <QMutex>
 #include <QSharedPointer>
@@ -675,7 +677,7 @@ private:
         int device;
         int subdevice;
         QString name;
-        long resolution;
+        long resolution;  // usecs
     };
     std::vector<AlsaTimerInfo> m_timers;
     QString m_currentTimerName;
@@ -823,6 +825,11 @@ private:
     TransportSyncStatus m_mmcStatus;
     TransportSyncStatus m_mtcStatus;
 
+    void sendEvent(
+            bool isSoftSynth,
+            InstrumentId instrumentID,
+            snd_seq_event_t &alsaEvent,
+            bool now);
 };
 
 
