@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -99,7 +99,7 @@ ControlBlock::setDocument(RosegardenDocument *doc)
 
     Composition& comp = m_doc->getComposition();
 
-    for (Composition::trackiterator i = comp.getTracks().begin();
+    for (Composition::TrackMap::iterator i = comp.getTracks().begin();
 	 i != comp.getTracks().end(); ++i) {
         Track *track = i->second;
         if (!track) continue;
