@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -14,20 +14,22 @@
 */
 
 #define RG_MODULE_STRING "[JackDriver]"
-#define RG_NO_DEBUG_PRINT 1
+#define RG_NO_DEBUG_PRINT
 
 #include "JackDriver.h"
+
 #include "AlsaDriver.h"
 #include "MappedStudio.h"
 #include "AudioProcess.h"
 #include "AudioInstrumentMixer.h"
-#include "base/Profiler.h"
-#include "base/AudioLevel.h"
 #include "Audit.h"
 #include "PluginFactory.h"
 #include "SequencerDataBlock.h"
-#include "sound/WAVExporter.h"
 
+#include "base/Profiler.h"
+#include "base/AudioLevel.h"
+#include "sound/WAVExporter.h"
+#include "sequencer/RosegardenSequencer.h"
 #include "misc/ConfigGroups.h"
 #include "misc/Debug.h"
 #include "misc/Preferences.h"
@@ -39,10 +41,10 @@
 #ifdef HAVE_ALSA
 #ifdef HAVE_LIBJACK
 
-//#define DEBUG_JACK_DRIVER 1
-//#define DEBUG_JACK_TRANSPORT 1
-//#define DEBUG_JACK_PROCESS 1
-//#define DEBUG_JACK_XRUN 1
+//#define DEBUG_JACK_DRIVER
+//#define DEBUG_JACK_TRANSPORT
+//#define DEBUG_JACK_PROCESS
+//#define DEBUG_JACK_XRUN
 
 namespace Rosegarden
 {
@@ -319,6 +321,8 @@ JackDriver::initialise(bool reinitialise)
         return ;
     }
 
+    // Start with an initial single stereo input pair so that we can
+    // make the default connections.  See connectDefaultInputs below.
     if (!createRecordInputs(1)) {
         RG_WARNING << "initialise() - failed to create record inputs!";
         AUDIT << "WARNING: failed to create record inputs!\n";
@@ -332,17 +336,27 @@ JackDriver::initialise(bool reinitialise)
     }
 
     // Now set up the default connections, if configured to do so
-    settings.beginGroup(SequencerOptionsConfigGroup);
-    bool connectDefaultOutputs = settings.value("connect_default_jack_outputs", true).toBool();
-    bool connectDefaultInputs = settings.value("connect_default_jack_inputs", true).toBool();
-    settings.endGroup();
 
-    const char **ports = jack_get_ports(m_client, nullptr, nullptr,
-            JackPortIsPhysical | JackPortIsInput);
+    // Set up the outputs.
+    // E.g. "rosegarden:master out L" and "rosegarden:master out R" to
+    // "system:playback_1" and "system:playback_2".
+
+    settings.beginGroup(SequencerOptionsConfigGroup);
+    const bool connectDefaultOutputs =
+            settings.value("connect_default_jack_outputs", true).toBool();
+    settings.endGroup();
 
     if (connectDefaultOutputs) {
 
-        std::string playback_1, playback_2;
+        // Get the physical input ports.
+        const char **ports = jack_get_ports(
+                m_client,  // client
+                nullptr,  // port_name_pattern
+                nullptr,  // type_name_pattern
+                JackPortIsPhysical | JackPortIsInput);  // flags
+
+        std::string playback_1;
+        std::string playback_2;
 
         if (ports) {
             if (ports[0])
@@ -414,26 +428,42 @@ JackDriver::initialise(bool reinitialise)
         AUDIT << "  Go to Edit > Preferences > Audio > Make default JACK connections.\n";
     }
 
+    // Set up the inputs.
+    // E.g. "system:capture_1" and "system:capture_1" to
+    // "rosegarden:record in 1 L" and "rosegarden:record in 1 R".
+
+    settings.beginGroup(SequencerOptionsConfigGroup);
+    const bool connectDefaultInputs =
+            settings.value("connect_default_jack_inputs", true).toBool();
+    settings.endGroup();
+
     if (connectDefaultInputs) {
 
-        std::string capture_1, capture_2;
+        // We only look at the first two.
+        std::string capture_1;
+        std::string capture_2;
 
-        ports =
-            jack_get_ports(m_client, nullptr, nullptr,
-                           JackPortIsPhysical | JackPortIsOutput);
+        // Get the output ports.  Usually system:capture_1 and system:capture_2
+        // are the first two.
+        const char **ports = jack_get_ports(
+                m_client,  // client
+                nullptr,  // port_name_pattern
+                nullptr,  // type_name_pattern
+                JackPortIsPhysical | JackPortIsOutput);  // flags
 
         if (ports) {
-            if (ports[0])
+            unsigned int count = 0;
+            if (ports[0]) {
                 capture_1 = std::string(ports[0]);
-            if (ports[1])
+                ++count;
+            }
+            if (ports[1]) {
                 capture_2 = std::string(ports[1]);
+                ++count;
+            }
 
-            // count ports
-            unsigned int i = 0;
-            for (i = 0; ports[i]; i++)
-                ;
-            RG_DEBUG << "initialise() - found " << i << " JACK physical inputs";
-            AUDIT << "found " << i << " JACK physical inputs\n";
+            RG_DEBUG << "initialise() - found " << count << " JACK physical inputs";
+            AUDIT << "found " << count << " JACK physical inputs\n";
 
             jack_free(ports);
 
@@ -444,11 +474,14 @@ JackDriver::initialise(bool reinitialise)
 
         if (capture_1 != "") {
 
-            RG_DEBUG << "initialise() - connecting from " << "\"" << capture_1.c_str() << "\" to \"" << jack_port_name(m_inputPorts[0]) << "\"";
-            AUDIT << "connecting from " << "\"" << capture_1.c_str() << "\" to \"" << jack_port_name(m_inputPorts[0]) << "\"\n";
+            std::string recordIn1L = jack_port_name(m_inputPorts[0]);
 
-            if (jack_connect(m_client, capture_1.c_str(),
-                             jack_port_name(m_inputPorts[0]))) {
+            RG_DEBUG << "initialise() - connecting from " << "\"" << capture_1 << "\" to \"" << recordIn1L << "\"";
+            AUDIT << "connecting from " << "\"" << capture_1 << "\" to \"" << recordIn1L << "\"\n";
+
+            if (jack_connect(m_client,  // client
+                             capture_1.c_str(),  // source_port
+                             recordIn1L.c_str())) {  // destination_port
                 RG_WARNING << "initialise() - cannot connect to JACK input port";
                 AUDIT << "WARNING: cannot connect to JACK input port\n";
             }
@@ -456,11 +489,14 @@ JackDriver::initialise(bool reinitialise)
 
         if (capture_2 != "") {
 
-            RG_DEBUG << "initialise() - connecting from " << "\"" << capture_2.c_str() << "\" to \"" << jack_port_name(m_inputPorts[1]) << "\"";
-            AUDIT << "connecting from " << "\"" << capture_2.c_str() << "\" to \"" << jack_port_name(m_inputPorts[1]) << "\"\n";
+            std::string recordIn1R = jack_port_name(m_inputPorts[1]);
 
-            if (jack_connect(m_client, capture_2.c_str(),
-                             jack_port_name(m_inputPorts[1]))) {
+            RG_DEBUG << "initialise() - connecting from " << "\"" << capture_2 << "\" to \"" << recordIn1R << "\"";
+            AUDIT << "connecting from " << "\"" << capture_2 << "\" to \"" << recordIn1R << "\"\n";
+
+            if (jack_connect(m_client,  // client
+                             capture_2.c_str(),  // source_port
+                             recordIn1R.c_str())) {  // destination_port
                 RG_WARNING << "initialise() - cannot connect to JACK input port";
                 AUDIT << "WARNING: cannot connect to JACK input port\n";
             }
@@ -618,21 +654,29 @@ JackDriver::createSubmasterOutputs(int pairs)
 }
 
 bool
-JackDriver::createRecordInputs(int pairs)
+JackDriver::createRecordInputs(int newPairs)
 {
     if (!m_client)
         return false;
 
-    int pairsNow = int(m_inputPorts.size()) / 2;
-    if (pairs == pairsNow)
+    // Don't allow zero pairs.
+    if (newPairs < 1)
+        newPairs = 1;
+
+    const int oldPairs = int(m_inputPorts.size()) / 2;
+    // No change or a reduction?  Bail.
+    if (newPairs <= oldPairs)
         return true;
 
-    for (int i = pairsNow; i < pairs; ++i) {
+    // For each additional input port pair...
+    for (int pairNumber = oldPairs + 1; pairNumber <= newPairs; ++pairNumber) {
 
         QString name;
         jack_port_t *port;
 
-        name = QString("record in %1 L").arg(i + 1);
+        // Register the Left.
+
+        name = QString("record in %1 L").arg(pairNumber);
         port = jack_port_register(m_client,
                                   name.toLocal8Bit(),
                                   JACK_DEFAULT_AUDIO_TYPE,
@@ -640,9 +684,12 @@ JackDriver::createRecordInputs(int pairs)
                                   0);
         if (!port)
             return false;
+
         m_inputPorts.push_back(port);
 
-        name = QString("record in %1 R").arg(i + 1);
+        // Register the Right.
+
+        name = QString("record in %1 R").arg(pairNumber);
         port = jack_port_register(m_client,
                                   name.toLocal8Bit(),
                                   JACK_DEFAULT_AUDIO_TYPE,
@@ -650,15 +697,29 @@ JackDriver::createRecordInputs(int pairs)
                                   0);
         if (!port)
             return false;
+
         m_inputPorts.push_back(port);
     }
 
-    while ((int)m_inputPorts.size() > pairs * 2) {
-        std::vector<jack_port_t *>::iterator itr = m_inputPorts.end();
-        --itr;
+#if 0
+    // ??? Removing this since it will cause connections to be dropped.
+    //     If the user goes from a Composition with 4 inputs to one with
+    //     2 inputs, there's no need to delete input ports.  In fact,
+    //     there used to be a bug here where the input ports would never
+    //     be deleted.  No one complained.
+    //
+    //     I suspect the real solution would be to implement JACK input
+    //     connections the way we do MIDI input connections.  Try to find
+    //     all the ports and connect to them on Composition load.
+
+    // Delete any extra ports if we've gone down from say 2 pairs to 1.
+
+    while ((int)m_inputPorts.size() > newPairs * 2) {
+        std::vector<jack_port_t *>::iterator itr = m_inputPorts.end() - 1;
         jack_port_unregister(m_client, *itr);
         m_inputPorts.erase(itr);
     }
+#endif
 
     return true;
 }
@@ -1595,20 +1656,32 @@ JackDriver::jackProcessRecord(InstrumentId id,
     return 0;
 }
 
+#ifdef DEBUG_JACK_TRANSPORT
+static QString transportStateToString(jack_transport_state_t state)
+{
+    static std::vector<QString> states{
+        "Stopped", "Rolling", "Looping", "Starting", "NetStarting"};
+
+    if (state < 0  ||  state >= states.size())
+        return "???";
+
+    return states[state];
+}
+#endif
 
 int
 JackDriver::jackSyncCallback(jack_transport_state_t state,
                              jack_position_t *position,
                              void *arg)
 {
-    JackDriver *inst = static_cast<JackDriver *>(arg);
-    if (!inst)
-        return true; // or rather, return "huh?"
+    JackDriver *jackDriver = static_cast<JackDriver *>(arg);
+    if (!jackDriver)
+        return true;
 
-    inst->m_alsaDriver->checkTimerSync(0); // reset, as not processing
+    jackDriver->m_alsaDriver->checkTimerSync(0); // reset, as not processing
 
-    if (!inst->m_jackTransportEnabled)
-        return true; // ignore
+    if (!jackDriver->m_jackTransportEnabled)
+        return true;
 
     RosegardenSequencer *sequencer =
             RosegardenSequencer::getInstance();
@@ -1617,16 +1690,26 @@ JackDriver::jackSyncCallback(jack_transport_state_t state,
 
 #ifdef DEBUG_JACK_TRANSPORT
 
-    RG_DEBUG << "jackSyncCallback(): state " << state << " [" << (state == 0 ? "stopped" : state == 1 ? "rolling" : state == 2 ? "looping" : state == 3 ? "starting" : "unknown") << "], frame " << position->frame << ", waiting " << inst->m_waiting << ", playing " << inst->m_alsaDriver->isPlaying();
-    RG_DEBUG << "jackSyncCallback(): m_waitingState " << inst->m_waitingState << ", unique_1 " << position->unique_1 << ", unique_2 " << position->unique_2;
-    RG_DEBUG << "jackSyncCallback(): rate " << position->frame_rate << ", bar " << position->bar << ", beat " << position->beat << ", tick " << position->tick << ", bpm " << position->beats_per_minute;
+    RG_DEBUG << "jackSyncCallback() ----------";
+    RG_DEBUG << "    state:" << state << transportStateToString(state);
+    RG_DEBUG << "    frame_rate:" << position->frame_rate << "| frame:" << position->frame << "| frame secs:" << (double)position->frame / (double)position->frame_rate;
+    //RG_DEBUG << "    usecs:" << position->usecs;  // Free-rolling timestamp.  Not very useful.
+    if (position->valid & JackPositionBBT)
+        RG_DEBUG << "    bar:" << position->bar << "| beat:" << position->beat << "| tick:" << position->tick << "| bpm:" << position->beats_per_minute;
+    if (position->unique_1 != position->unique_2)
+        RG_DEBUG << "    INCONSISTENT! unique_1:" << position->unique_1 << "| unique_2:" << position->unique_2;
+    RG_DEBUG << "    ALSA playing:" << jackDriver->m_alsaDriver->isPlaying();
+    RG_DEBUG << "    m_waiting:" << jackDriver->m_waiting << "| m_waitingState:" << jackDriver->m_waitingState << transportStateToString(jackDriver->m_waitingState);
 
 #endif
 
+    // Infer the transport request from the ALSA play state and the
+    // incoming JACK transport state.
+
     RosegardenSequencer::TransportRequest request =
             RosegardenSequencer::TransportNoChange;
 
-    if (inst->m_alsaDriver->isPlaying()) {
+    if (jackDriver->m_alsaDriver->isPlaying()) {
 
         if (state == JackTransportStarting) {
             request = RosegardenSequencer::TransportJumpToTime;
@@ -1634,16 +1717,29 @@ JackDriver::jackSyncCallback(jack_transport_state_t state,
             request = RosegardenSequencer::TransportStop;
         }
 
-    } else {
+    } else {  // ALSA is stopped.
 
         if (state == JackTransportStarting) {
             request = RosegardenSequencer::TransportStartAtTime;
         } else if (state == JackTransportStopped) {
+            // ??? Not necessarily.  If the position has changed, we probably
+            //     want to seek to that new position.  Since we are stopped and
+            //     these requests come in extremely rarely, we should probably
+            //     just assume that we need to do a position update.
             request = RosegardenSequencer::TransportNoChange;
+            // ??? But this results in an endless loop.  I'm guessing it is
+            //     because we send out a transport jump to JACK which then
+            //     sends another to us.
+            //request = RosegardenSequencer::TransportJumpToTime;
         }
     }
 
-    if (!inst->m_waiting || inst->m_waitingState != state) {
+#ifdef DEBUG_JACK_TRANSPORT
+    RG_DEBUG << "    inferred request:" << request << RosegardenSequencer::transportRequestToString(request);
+#endif
+
+    // If we aren't waiting, or the state has changed...
+    if (!jackDriver->m_waiting  ||  jackDriver->m_waitingState != state) {
 
         if (request == RosegardenSequencer::TransportJumpToTime ||
                 request == RosegardenSequencer::TransportStartAtTime) {
@@ -1652,64 +1748,69 @@ JackDriver::jackSyncCallback(jack_transport_state_t state,
                                                    position->frame_rate);
 
 #ifdef DEBUG_JACK_TRANSPORT
-            RG_DEBUG << "jackSyncCallback(): Requesting jump to " << rt;
+            RG_DEBUG << "    Requesting jump to " << rt;
 #endif
 
-            inst->m_waitingToken = sequencer->transportJump(request, rt);
+            jackDriver->m_waitingToken = sequencer->transportJump(request, rt);
 
 #ifdef DEBUG_JACK_TRANSPORT
-            RG_DEBUG << "jackSyncCallback(): My token is " << inst->m_waitingToken;
+            RG_DEBUG << "    My token is " << jackDriver->m_waitingToken;
 #endif
 
         } else if (request == RosegardenSequencer::TransportStop) {
 
 #ifdef DEBUG_JACK_TRANSPORT
-            RG_DEBUG << "jackSyncCallback(): Requesting state change to " << request;
+            RG_DEBUG << "    Requesting state change to " << request;
 #endif
 
-            inst->m_waitingToken = sequencer->transportChange(request);
+            jackDriver->m_waitingToken = sequencer->transportChange(request);
 
 #ifdef DEBUG_JACK_TRANSPORT
-            RG_DEBUG << "jackSyncCallback(): My token is " << inst->m_waitingToken;
+            RG_DEBUG << "    My token is " << jackDriver->m_waitingToken;
 #endif
 
         } else if (request == RosegardenSequencer::TransportNoChange) {
 
 #ifdef DEBUG_JACK_TRANSPORT
-            RG_DEBUG << "jackSyncCallback(): Requesting no state change!";
+            RG_DEBUG << "    Requesting no state change!";
 #endif
 
-            inst->m_waitingToken = sequencer->transportChange(request);
+            // ??? Why are we requesting a token for no change?  Why
+            //     don't we just return true?
+            jackDriver->m_waitingToken = sequencer->transportChange(request);
 
 #ifdef DEBUG_JACK_TRANSPORT
-            RG_DEBUG << "jackSyncCallback(): My token is " << inst->m_waitingToken;
+            RG_DEBUG << "    My token is " << jackDriver->m_waitingToken;
 #endif
 
         }
 
-        inst->m_waiting = true;
-        inst->m_waitingState = state;
+        jackDriver->m_waiting = true;
+        jackDriver->m_waitingState = state;
 
 #ifdef DEBUG_JACK_TRANSPORT
-        RG_DEBUG << "jackSyncCallback(): Setting waiting to " << inst->m_waiting << " and waiting state to " << inst->m_waitingState << " (request was " << request << ")";
+        RG_DEBUG << "    Setting m_waiting to true and waiting state to" << jackDriver->m_waitingState << transportStateToString(jackDriver->m_waitingState) << "(request was" << request << ")";
 #endif
 
-        return 0;
+        // Not done.  We need another call to confirm transport sync.
+        return false;
 
-    } else {
+    } else {  // waiting and the state has not changed
 
-        if (sequencer->isTransportSyncComplete(inst->m_waitingToken)) {
+        if (sequencer->isTransportSyncComplete(jackDriver->m_waitingToken)) {
 #ifdef DEBUG_JACK_TRANSPORT
-            RG_DEBUG << "jackSyncCallback(): Sync complete";
+            RG_DEBUG << "    RG transport sync complete";
 #endif
 
-            return 1;
+            // Done.  We have confirmed transport is ready.
+            return true;
         } else {
 #ifdef DEBUG_JACK_TRANSPORT
-            RG_DEBUG << "jackSyncCallback(): Sync not complete";
+            RG_DEBUG << "    RG transport sync not complete";
 #endif
 
-            return 0;
+            // Not done.  We need another call to confirm transport sync.
+            return false;
         }
     }
 }
@@ -2188,13 +2289,17 @@ JackDriver::updateAudioData()
     m_directMasterAudioInstruments = directMasterAudioInstruments;
     m_directMasterSynthInstruments = directMasterSynthInstruments;
 
-    int inputs = m_alsaDriver->getMappedStudio()->
+    // Update the number of record inputs.
+    const int inputs = m_alsaDriver->getMappedStudio()->
                  getObjectCount(MappedObject::AudioInput);
-
-    if (m_client) {
-        // this will return with no work if the inputs are already correct:
-        createRecordInputs(inputs);
-    }
+    // Does no work if the inputs are already correct.
+    // ??? Why are we doing this in updateAudioData()?!  We should be doing
+    //     this when we load a new document and when the user changes it
+    //     in the document (via the audio mixer).  This is getting called
+    //     *constantly* on the JACK audio thread.  Does it need to be on the
+    //     JACK audio thread?  Or can we safely call it from the GUI
+    //     thread?
+    createRecordInputs(inputs);
 
     m_bussMixer->updateInstrumentConnections();
     m_instrumentMixer->updateInstrumentMuteStates();
