@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -27,8 +27,8 @@
 
 #include <lv2/options/options.h>
 
-#include <alsa/seq_event.h>
-#include <alsa/seq_midi_event.h>  // for snd_midi_event_t
+// Forward declare from alsa/asoundlib.h
+typedef struct snd_midi_event snd_midi_event_t;
 
 #include <QString>
 #include <QMutex>
