@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -79,7 +79,7 @@ class MappedStudio;
 class SoundDriver
 {
 public:
-    SoundDriver(MappedStudio *studio, const QString &name);
+    SoundDriver(MappedStudio *studio, const QString &versionInfo);
     virtual ~SoundDriver();
 
 
@@ -335,8 +335,8 @@ protected:
 
     // *** General ***
 
-    /// Driver name for the audit log.
-    QString m_name;
+    /// Traditionally used to dump version info to the audit log.
+    QString m_versionInfo;
 
     SoundDriverStatus m_driverStatus;
 
